# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from hyperlane.warp.v1 import tx_pb2 as hyperlane_dot_warp_dot_v1_dot_tx__pb2


class MsgStub(object):
    """Msg defines the module Msg service.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CreateCollateralToken = channel.unary_unary(
                '/hyperlane.warp.v1.Msg/CreateCollateralToken',
                request_serializer=hyperlane_dot_warp_dot_v1_dot_tx__pb2.MsgCreateCollateralToken.SerializeToString,
                response_deserializer=hyperlane_dot_warp_dot_v1_dot_tx__pb2.MsgCreateCollateralTokenResponse.FromString,
                _registered_method=True)
        self.CreateSyntheticToken = channel.unary_unary(
                '/hyperlane.warp.v1.Msg/CreateSyntheticToken',
                request_serializer=hyperlane_dot_warp_dot_v1_dot_tx__pb2.MsgCreateSyntheticToken.SerializeToString,
                response_deserializer=hyperlane_dot_warp_dot_v1_dot_tx__pb2.MsgCreateSyntheticTokenResponse.FromString,
                _registered_method=True)
        self.CreateNativeSyntheticToken = channel.unary_unary(
                '/hyperlane.warp.v1.Msg/CreateNativeSyntheticToken',
                request_serializer=hyperlane_dot_warp_dot_v1_dot_tx__pb2.MsgCreateNativeSyntheticToken.SerializeToString,
                response_deserializer=hyperlane_dot_warp_dot_v1_dot_tx__pb2.MsgCreateSyntheticTokenResponse.FromString,
                _registered_method=True)
        self.SetToken = channel.unary_unary(
                '/hyperlane.warp.v1.Msg/SetToken',
                request_serializer=hyperlane_dot_warp_dot_v1_dot_tx__pb2.MsgSetToken.SerializeToString,
                response_deserializer=hyperlane_dot_warp_dot_v1_dot_tx__pb2.MsgSetTokenResponse.FromString,
                _registered_method=True)
        self.EnrollRemoteRouter = channel.unary_unary(
                '/hyperlane.warp.v1.Msg/EnrollRemoteRouter',
                request_serializer=hyperlane_dot_warp_dot_v1_dot_tx__pb2.MsgEnrollRemoteRouter.SerializeToString,
                response_deserializer=hyperlane_dot_warp_dot_v1_dot_tx__pb2.MsgEnrollRemoteRouterResponse.FromString,
                _registered_method=True)
        self.UnrollRemoteRouter = channel.unary_unary(
                '/hyperlane.warp.v1.Msg/UnrollRemoteRouter',
                request_serializer=hyperlane_dot_warp_dot_v1_dot_tx__pb2.MsgUnrollRemoteRouter.SerializeToString,
                response_deserializer=hyperlane_dot_warp_dot_v1_dot_tx__pb2.MsgUnrollRemoteRouterResponse.FromString,
                _registered_method=True)
        self.RemoteTransfer = channel.unary_unary(
                '/hyperlane.warp.v1.Msg/RemoteTransfer',
                request_serializer=hyperlane_dot_warp_dot_v1_dot_tx__pb2.MsgRemoteTransfer.SerializeToString,
                response_deserializer=hyperlane_dot_warp_dot_v1_dot_tx__pb2.MsgRemoteTransferResponse.FromString,
                _registered_method=True)


class MsgServicer(object):
    """Msg defines the module Msg service.
    """

    def CreateCollateralToken(self, request, context):
        """CreateCollateralToken ...
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateSyntheticToken(self, request, context):
        """CreateSyntheticToken ...
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateNativeSyntheticToken(self, request, context):
        """CreateNativeSyntheticToken ...
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetToken(self, request, context):
        """SetToken ...
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def EnrollRemoteRouter(self, request, context):
        """EnrollRemoteRouter ...
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UnrollRemoteRouter(self, request, context):
        """UnrollRemoteRouter ...
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RemoteTransfer(self, request, context):
        """RemoteTransfer ...
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_MsgServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'CreateCollateralToken': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateCollateralToken,
                    request_deserializer=hyperlane_dot_warp_dot_v1_dot_tx__pb2.MsgCreateCollateralToken.FromString,
                    response_serializer=hyperlane_dot_warp_dot_v1_dot_tx__pb2.MsgCreateCollateralTokenResponse.SerializeToString,
            ),
            'CreateSyntheticToken': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateSyntheticToken,
                    request_deserializer=hyperlane_dot_warp_dot_v1_dot_tx__pb2.MsgCreateSyntheticToken.FromString,
                    response_serializer=hyperlane_dot_warp_dot_v1_dot_tx__pb2.MsgCreateSyntheticTokenResponse.SerializeToString,
            ),
            'CreateNativeSyntheticToken': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateNativeSyntheticToken,
                    request_deserializer=hyperlane_dot_warp_dot_v1_dot_tx__pb2.MsgCreateNativeSyntheticToken.FromString,
                    response_serializer=hyperlane_dot_warp_dot_v1_dot_tx__pb2.MsgCreateSyntheticTokenResponse.SerializeToString,
            ),
            'SetToken': grpc.unary_unary_rpc_method_handler(
                    servicer.SetToken,
                    request_deserializer=hyperlane_dot_warp_dot_v1_dot_tx__pb2.MsgSetToken.FromString,
                    response_serializer=hyperlane_dot_warp_dot_v1_dot_tx__pb2.MsgSetTokenResponse.SerializeToString,
            ),
            'EnrollRemoteRouter': grpc.unary_unary_rpc_method_handler(
                    servicer.EnrollRemoteRouter,
                    request_deserializer=hyperlane_dot_warp_dot_v1_dot_tx__pb2.MsgEnrollRemoteRouter.FromString,
                    response_serializer=hyperlane_dot_warp_dot_v1_dot_tx__pb2.MsgEnrollRemoteRouterResponse.SerializeToString,
            ),
            'UnrollRemoteRouter': grpc.unary_unary_rpc_method_handler(
                    servicer.UnrollRemoteRouter,
                    request_deserializer=hyperlane_dot_warp_dot_v1_dot_tx__pb2.MsgUnrollRemoteRouter.FromString,
                    response_serializer=hyperlane_dot_warp_dot_v1_dot_tx__pb2.MsgUnrollRemoteRouterResponse.SerializeToString,
            ),
            'RemoteTransfer': grpc.unary_unary_rpc_method_handler(
                    servicer.RemoteTransfer,
                    request_deserializer=hyperlane_dot_warp_dot_v1_dot_tx__pb2.MsgRemoteTransfer.FromString,
                    response_serializer=hyperlane_dot_warp_dot_v1_dot_tx__pb2.MsgRemoteTransferResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'hyperlane.warp.v1.Msg', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('hyperlane.warp.v1.Msg', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class Msg(object):
    """Msg defines the module Msg service.
    """

    @staticmethod
    def CreateCollateralToken(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/hyperlane.warp.v1.Msg/CreateCollateralToken',
            hyperlane_dot_warp_dot_v1_dot_tx__pb2.MsgCreateCollateralToken.SerializeToString,
            hyperlane_dot_warp_dot_v1_dot_tx__pb2.MsgCreateCollateralTokenResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def CreateSyntheticToken(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/hyperlane.warp.v1.Msg/CreateSyntheticToken',
            hyperlane_dot_warp_dot_v1_dot_tx__pb2.MsgCreateSyntheticToken.SerializeToString,
            hyperlane_dot_warp_dot_v1_dot_tx__pb2.MsgCreateSyntheticTokenResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def CreateNativeSyntheticToken(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/hyperlane.warp.v1.Msg/CreateNativeSyntheticToken',
            hyperlane_dot_warp_dot_v1_dot_tx__pb2.MsgCreateNativeSyntheticToken.SerializeToString,
            hyperlane_dot_warp_dot_v1_dot_tx__pb2.MsgCreateSyntheticTokenResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def SetToken(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/hyperlane.warp.v1.Msg/SetToken',
            hyperlane_dot_warp_dot_v1_dot_tx__pb2.MsgSetToken.SerializeToString,
            hyperlane_dot_warp_dot_v1_dot_tx__pb2.MsgSetTokenResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def EnrollRemoteRouter(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/hyperlane.warp.v1.Msg/EnrollRemoteRouter',
            hyperlane_dot_warp_dot_v1_dot_tx__pb2.MsgEnrollRemoteRouter.SerializeToString,
            hyperlane_dot_warp_dot_v1_dot_tx__pb2.MsgEnrollRemoteRouterResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def UnrollRemoteRouter(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/hyperlane.warp.v1.Msg/UnrollRemoteRouter',
            hyperlane_dot_warp_dot_v1_dot_tx__pb2.MsgUnrollRemoteRouter.SerializeToString,
            hyperlane_dot_warp_dot_v1_dot_tx__pb2.MsgUnrollRemoteRouterResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def RemoteTransfer(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/hyperlane.warp.v1.Msg/RemoteTransfer',
            hyperlane_dot_warp_dot_v1_dot_tx__pb2.MsgRemoteTransfer.SerializeToString,
            hyperlane_dot_warp_dot_v1_dot_tx__pb2.MsgRemoteTransferResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: hyperlane/warp/v1/genesis.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from hyperlane.warp.v1 import types_pb2 as hyperlane_dot_warp_dot_v1_dot_types__pb2
from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1fhyperlane/warp/v1/genesis.proto\x12\x11hyperlane.warp.v1\x1a\x1dhyperlane/warp/v1/types.proto\x1a\x14gogoproto/gogo.proto\"\xde\x01\n\x0cGenesisState\x12\x37\n\x06params\x18\x01 \x01(\x0b\x32\x19.hyperlane.warp.v1.ParamsB\x04\xc8\xde\x1f\x00R\x06params\x12\x39\n\x06tokens\x18\x02 \x03(\x0b\x32\x1b.hyperlane.warp.v1.HypTokenB\x04\xc8\xde\x1f\x00R\x06tokens\x12Z\n\x0eremote_routers\x18\x03 \x03(\x0b\x32-.hyperlane.warp.v1.GenesisRemoteRouterWrapperB\x04\xc8\xde\x1f\x00R\rremoteRouters\"\x83\x01\n\x1aGenesisRemoteRouterWrapper\x12\x19\n\x08token_id\x18\x01 \x01(\x04R\x07tokenId\x12J\n\rremote_router\x18\x02 \x01(\x0b\x32\x1f.hyperlane.warp.v1.RemoteRouterB\x04\xc8\xde\x1f\x00R\x0cremoteRouterB\xc5\x01\n\x15\x63om.hyperlane.warp.v1B\x0cGenesisProtoP\x01Z8github.com/bcp-innovations/hyperlane-cosmos/x/warp/types\xa2\x02\x03HWX\xaa\x02\x11Hyperlane.Warp.V1\xca\x02\x11Hyperlane\\Warp\\V1\xe2\x02\x1dHyperlane\\Warp\\V1\\GPBMetadata\xea\x02\x13Hyperlane::Warp::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'hyperlane.warp.v1.genesis_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\025com.hyperlane.warp.v1B\014GenesisProtoP\001Z8github.com/bcp-innovations/hyperlane-cosmos/x/warp/types\242\002\003HWX\252\002\021Hyperlane.Warp.V1\312\002\021Hyperlane\\Warp\\V1\342\002\035Hyperlane\\Warp\\V1\\GPBMetadata\352\002\023Hyperlane::Warp::V1'
  _globals['_GENESISSTATE'].fields_by_name['params']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _globals['_GENESISSTATE'].fields_by_name['tokens']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['tokens']._serialized_options = b'\310\336\037\000'
  _globals['_GENESISSTATE'].fields_by_name['remote_routers']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['remote_routers']._serialized_options = b'\310\336\037\000'
  _globals['_GENESISREMOTEROUTERWRAPPER'].fields_by_name['remote_router']._loaded_options = None
  _globals['_GENESISREMOTEROUTERWRAPPER'].fields_by_name['remote_router']._serialized_options = b'\310\336\037\000'
  _globals['_GENESISSTATE']._serialized_start=108
  _globals['_GENESISSTATE']._serialized_end=330
  _globals['_GENESISREMOTEROUTERWRAPPER']._serialized_start=333
  _globals['_GENESISREMOTEROUTERWRAPPER']._serialized_end=464
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/downtimedetector/v1beta1/downtime_duration.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n:injective/downtimedetector/v1beta1/downtime_duration.proto\x12\"injective.downtimedetector.v1beta1\x1a\x14gogoproto/gogo.proto*\xfa\x06\n\x08\x44owntime\x12\"\n\x0c\x44URATION_30S\x10\x00\x1a\x10\x8a\x9d \x0c\x44URATION_30S\x12 \n\x0b\x44URATION_1M\x10\x01\x1a\x0f\x8a\x9d \x0b\x44URATION_1M\x12 \n\x0b\x44URATION_2M\x10\x02\x1a\x0f\x8a\x9d \x0b\x44URATION_2M\x12 \n\x0b\x44URATION_3M\x10\x03\x1a\x0f\x8a\x9d \x0b\x44URATION_3M\x12 \n\x0b\x44URATION_4M\x10\x04\x1a\x0f\x8a\x9d \x0b\x44URATION_4M\x12 \n\x0b\x44URATION_5M\x10\x05\x1a\x0f\x8a\x9d \x0b\x44URATION_5M\x12\"\n\x0c\x44URATION_10M\x10\x06\x1a\x10\x8a\x9d \x0c\x44URATION_10M\x12\"\n\x0c\x44URATION_20M\x10\x07\x1a\x10\x8a\x9d \x0c\x44URATION_20M\x12\"\n\x0c\x44URATION_30M\x10\x08\x1a\x10\x8a\x9d \x0c\x44URATION_30M\x12\"\n\x0c\x44URATION_40M\x10\t\x1a\x10\x8a\x9d \x0c\x44URATION_40M\x12\"\n\x0c\x44URATION_50M\x10\n\x1a\x10\x8a\x9d \x0c\x44URATION_50M\x12 \n\x0b\x44URATION_1H\x10\x0b\x1a\x0f\x8a\x9d \x0b\x44URATION_1H\x12$\n\rDURATION_1_5H\x10\x0c\x1a\x11\x8a\x9d \rDURATION_1_5H\x12 \n\x0b\x44URATION_2H\x10\r\x1a\x0f\x8a\x9d \x0b\x44URATION_2H\x12$\n\rDURATION_2_5H\x10\x0e\x1a\x11\x8a\x9d \rDURATION_2_5H\x12 \n\x0b\x44URATION_3H\x10\x0f\x1a\x0f\x8a\x9d \x0b\x44URATION_3H\x12 \n\x0b\x44URATION_4H\x10\x10\x1a\x0f\x8a\x9d \x0b\x44URATION_4H\x12 \n\x0b\x44URATION_5H\x10\x11\x1a\x0f\x8a\x9d \x0b\x44URATION_5H\x12 \n\x0b\x44URATION_6H\x10\x12\x1a\x0f\x8a\x9d \x0b\x44URATION_6H\x12 \n\x0b\x44URATION_9H\x10\x13\x1a\x0f\x8a\x9d \x0b\x44URATION_9H\x12\"\n\x0c\x44URATION_12H\x10\x14\x1a\x10\x8a\x9d \x0c\x44URATION_12H\x12\"\n\x0c\x44URATION_18H\x10\x15\x1a\x10\x8a\x9d \x0c\x44URATION_18H\x12\"\n\x0c\x44URATION_24H\x10\x16\x1a\x10\x8a\x9d \x0c\x44URATION_24H\x12\"\n\x0c\x44URATION_36H\x10\x17\x1a\x10\x8a\x9d \x0c\x44URATION_36H\x12\"\n\x0c\x44URATION_48H\x10\x18\x1a\x10\x8a\x9d \x0c\x44URATION_48HB\xc2\x02\n&com.injective.downtimedetector.v1beta1B\x15\x44owntimeDurationProtoP\x01ZWgithub.com/InjectiveLabs/injective-core/injective-chain/modules/downtime-detector/types\xa2\x02\x03IDX\xaa\x02\"Injective.Downtimedetector.V1beta1\xca\x02\"Injective\\Downtimedetector\\V1beta1\xe2\x02.Injective\\Downtimedetector\\V1beta1\\GPBMetadata\xea\x02$Injective::Downtimedetector::V1beta1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'injective.downtimedetector.v1beta1.downtime_duration_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n&com.injective.downtimedetector.v1beta1B\025DowntimeDurationProtoP\001ZWgithub.com/InjectiveLabs/injective-core/injective-chain/modules/downtime-detector/types\242\002\003IDX\252\002\"Injective.Downtimedetector.V1beta1\312\002\"Injective\\Downtimedetector\\V1beta1\342\002.Injective\\Downtimedetector\\V1beta1\\GPBMetadata\352\002$Injective::Downtimedetector::V1beta1'
  _globals['_DOWNTIME'].values_by_name["DURATION_30S"]._loaded_options = None
  _globals['_DOWNTIME'].values_by_name["DURATION_30S"]._serialized_options = b'\212\235 \014DURATION_30S'
  _globals['_DOWNTIME'].values_by_name["DURATION_1M"]._loaded_options = None
  _globals['_DOWNTIME'].values_by_name["DURATION_1M"]._serialized_options = b'\212\235 \013DURATION_1M'
  _globals['_DOWNTIME'].values_by_name["DURATION_2M"]._loaded_options = None
  _globals['_DOWNTIME'].values_by_name["DURATION_2M"]._serialized_options = b'\212\235 \013DURATION_2M'
  _globals['_DOWNTIME'].values_by_name["DURATION_3M"]._loaded_options = None
  _globals['_DOWNTIME'].values_by_name["DURATION_3M"]._serialized_options = b'\212\235 \013DURATION_3M'
  _globals['_DOWNTIME'].values_by_name["DURATION_4M"]._loaded_options = None
  _globals['_DOWNTIME'].values_by_name["DURATION_4M"]._serialized_options = b'\212\235 \013DURATION_4M'
  _globals['_DOWNTIME'].values_by_name["DURATION_5M"]._loaded_options = None
  _globals['_DOWNTIME'].values_by_name["DURATION_5M"]._serialized_options = b'\212\235 \013DURATION_5M'
  _globals['_DOWNTIME'].values_by_name["DURATION_10M"]._loaded_options = None
  _globals['_DOWNTIME'].values_by_name["DURATION_10M"]._serialized_options = b'\212\235 \014DURATION_10M'
  _globals['_DOWNTIME'].values_by_name["DURATION_20M"]._loaded_options = None
  _globals['_DOWNTIME'].values_by_name["DURATION_20M"]._serialized_options = b'\212\235 \014DURATION_20M'
  _globals['_DOWNTIME'].values_by_name["DURATION_30M"]._loaded_options = None
  _globals['_DOWNTIME'].values_by_name["DURATION_30M"]._serialized_options = b'\212\235 \014DURATION_30M'
  _globals['_DOWNTIME'].values_by_name["DURATION_40M"]._loaded_options = None
  _globals['_DOWNTIME'].values_by_name["DURATION_40M"]._serialized_options = b'\212\235 \014DURATION_40M'
  _globals['_DOWNTIME'].values_by_name["DURATION_50M"]._loaded_options = None
  _globals['_DOWNTIME'].values_by_name["DURATION_50M"]._serialized_options = b'\212\235 \014DURATION_50M'
  _globals['_DOWNTIME'].values_by_name["DURATION_1H"]._loaded_options = None
  _globals['_DOWNTIME'].values_by_name["DURATION_1H"]._serialized_options = b'\212\235 \013DURATION_1H'
  _globals['_DOWNTIME'].values_by_name["DURATION_1_5H"]._loaded_options = None
  _globals['_DOWNTIME'].values_by_name["DURATION_1_5H"]._serialized_options = b'\212\235 \rDURATION_1_5H'
  _globals['_DOWNTIME'].values_by_name["DURATION_2H"]._loaded_options = None
  _globals['_DOWNTIME'].values_by_name["DURATION_2H"]._serialized_options = b'\212\235 \013DURATION_2H'
  _globals['_DOWNTIME'].values_by_name["DURATION_2_5H"]._loaded_options = None
  _globals['_DOWNTIME'].values_by_name["DURATION_2_5H"]._serialized_options = b'\212\235 \rDURATION_2_5H'
  _globals['_DOWNTIME'].values_by_name["DURATION_3H"]._loaded_options = None
  _globals['_DOWNTIME'].values_by_name["DURATION_3H"]._serialized_options = b'\212\235 \013DURATION_3H'
  _globals['_DOWNTIME'].values_by_name["DURATION_4H"]._loaded_options = None
  _globals['_DOWNTIME'].values_by_name["DURATION_4H"]._serialized_options = b'\212\235 \013DURATION_4H'
  _globals['_DOWNTIME'].values_by_name["DURATION_5H"]._loaded_options = None
  _globals['_DOWNTIME'].values_by_name["DURATION_5H"]._serialized_options = b'\212\235 \013DURATION_5H'
  _globals['_DOWNTIME'].values_by_name["DURATION_6H"]._loaded_options = None
  _globals['_DOWNTIME'].values_by_name["DURATION_6H"]._serialized_options = b'\212\235 \013DURATION_6H'
  _globals['_DOWNTIME'].values_by_name["DURATION_9H"]._loaded_options = None
  _globals['_DOWNTIME'].values_by_name["DURATION_9H"]._serialized_options = b'\212\235 \013DURATION_9H'
  _globals['_DOWNTIME'].values_by_name["DURATION_12H"]._loaded_options = None
  _globals['_DOWNTIME'].values_by_name["DURATION_12H"]._serialized_options = b'\212\235 \014DURATION_12H'
  _globals['_DOWNTIME'].values_by_name["DURATION_18H"]._loaded_options = None
  _globals['_DOWNTIME'].values_by_name["DURATION_18H"]._serialized_options = b'\212\235 \014DURATION_18H'
  _globals['_DOWNTIME'].values_by_name["DURATION_24H"]._loaded_options = None
  _globals['_DOWNTIME'].values_by_name["DURATION_24H"]._serialized_options = b'\212\235 \014DURATION_24H'
  _globals['_DOWNTIME'].values_by_name["DURATION_36H"]._loaded_options = None
  _globals['_DOWNTIME'].values_by_name["DURATION_36H"]._serialized_options = b'\212\235 \014DURATION_36H'
  _globals['_DOWNTIME'].values_by_name["DURATION_48H"]._loaded_options = None
  _globals['_DOWNTIME'].values_by_name["DURATION_48H"]._serialized_options = b'\212\235 \014DURATION_48H'
  _globals['_DOWNTIME']._serialized_start=121
  _globals['_DOWNTIME']._serialized_end=1011
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: hyperlane/core/post_dispatch/v1/events.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,hyperlane/core/post_dispatch/v1/events.proto\x12\x1fhyperlane.core.post_dispatch.v1\x1a\x14gogoproto/gogo.proto\"\x89\x02\n\x19\x45ventCreateMerkleTreeHook\x12r\n\x13merkle_tree_hook_id\x18\x01 \x01(\tBC\xc8\xde\x1f\x00\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\x10merkleTreeHookId\x12\x62\n\nmailbox_id\x18\x02 \x01(\tBC\xc8\xde\x1f\x00\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\tmailboxId\x12\x14\n\x05owner\x18\x03 \x01(\tR\x05owner\"\x85\x02\n\x15\x45ventInsertedIntoTree\x12\x62\n\nmessage_id\x18\x01 \x01(\tBC\xc8\xde\x1f\x00\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\tmessageId\x12\x14\n\x05index\x18\x02 \x01(\rR\x05index\x12r\n\x13merkle_tree_hook_id\x18\x03 \x01(\tBC\xc8\xde\x1f\x00\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\x10merkleTreeHookId\"\xac\x02\n\x0f\x45ventGasPayment\x12\x62\n\nmessage_id\x18\x01 \x01(\tBC\xc8\xde\x1f\x00\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\tmessageId\x12 \n\x0b\x64\x65stination\x18\x02 \x01(\rR\x0b\x64\x65stination\x12\x1d\n\ngas_amount\x18\x03 \x01(\tR\tgasAmount\x12\x18\n\x07payment\x18\x04 \x01(\tR\x07payment\x12Z\n\x06igp_id\x18\x05 \x01(\tBC\xc8\xde\x1f\x00\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\x05igpId\"\x92\x01\n\x13\x45ventCreateNoopHook\x12\x65\n\x0cnoop_hook_id\x18\x01 \x01(\tBC\xc8\xde\x1f\x00\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\nnoopHookId\x12\x14\n\x05owner\x18\x02 \x01(\tR\x05owner\"\x98\x01\n\x0e\x45ventCreateIgp\x12Z\n\x06igp_id\x18\x01 \x01(\tBC\xc8\xde\x1f\x00\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\x05igpId\x12\x14\n\x05owner\x18\x02 \x01(\tR\x05owner\x12\x14\n\x05\x64\x65nom\x18\x03 \x01(\tR\x05\x64\x65nom\"\xcb\x01\n\x0b\x45ventSetIgp\x12Z\n\x06igp_id\x18\x01 \x01(\tBC\xc8\xde\x1f\x00\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\x05igpId\x12\x14\n\x05owner\x18\x02 \x01(\tR\x05owner\x12\x1b\n\tnew_owner\x18\x03 \x01(\tR\x08newOwner\x12-\n\x12renounce_ownership\x18\x04 \x01(\x08R\x11renounceOwnership\"\x82\x03\n\x1c\x45ventSetDestinationGasConfig\x12Z\n\x06igp_id\x18\x01 \x01(\tBC\xc8\xde\x1f\x00\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\x05igpId\x12\x14\n\x05owner\x18\x02 \x01(\tR\x05owner\x12#\n\rremote_domain\x18\x04 \x01(\rR\x0cremoteDomain\x12@\n\x0cgas_overhead\x18\x05 \x01(\tB\x1d\xc8\xde\x1f\x00\xda\xde\x1f\x15\x63osmossdk.io/math.IntR\x0bgasOverhead\x12:\n\tgas_price\x18\x06 \x01(\tB\x1d\xc8\xde\x1f\x00\xda\xde\x1f\x15\x63osmossdk.io/math.IntR\x08gasPrice\x12M\n\x13token_exchange_rate\x18\x07 \x01(\tB\x1d\xc8\xde\x1f\x00\xda\xde\x1f\x15\x63osmossdk.io/math.IntR\x11tokenExchangeRate\"\x99\x01\n\rEventClaimIgp\x12Z\n\x06igp_id\x18\x01 \x01(\tBC\xc8\xde\x1f\x00\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\x05igpId\x12\x14\n\x05owner\x18\x02 \x01(\tR\x05owner\x12\x16\n\x06\x61mount\x18\x03 \x01(\tR\x06\x61mountB\x98\x02\n#com.hyperlane.core.post_dispatch.v1B\x0b\x45ventsProtoP\x01ZIgithub.com/bcp-innovations/hyperlane-cosmos/x/core/02_post_dispatch/types\xa2\x02\x03HCP\xaa\x02\x1eHyperlane.Core.PostDispatch.V1\xca\x02\x1eHyperlane\\Core\\PostDispatch\\V1\xe2\x02*Hyperlane\\Core\\PostDispatch\\V1\\GPBMetadata\xea\x02!Hyperlane::Core::PostDispatch::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'hyperlane.core.post_dispatch.v1.events_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n#com.hyperlane.core.post_dispatch.v1B\013EventsProtoP\001ZIgithub.com/bcp-innovations/hyperlane-cosmos/x/core/02_post_dispatch/types\242\002\003HCP\252\002\036Hyperlane.Core.PostDispatch.V1\312\002\036Hyperlane\\Core\\PostDispatch\\V1\342\002*Hyperlane\\Core\\PostDispatch\\V1\\GPBMetadata\352\002!Hyperlane::Core::PostDispatch::V1'
  _globals['_EVENTCREATEMERKLETREEHOOK'].fields_by_name['merkle_tree_hook_id']._loaded_options = None
  _globals['_EVENTCREATEMERKLETREEHOOK'].fields_by_name['merkle_tree_hook_id']._serialized_options = b'\310\336\037\000\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_EVENTCREATEMERKLETREEHOOK'].fields_by_name['mailbox_id']._loaded_options = None
  _globals['_EVENTCREATEMERKLETREEHOOK'].fields_by_name['mailbox_id']._serialized_options = b'\310\336\037\000\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_EVENTINSERTEDINTOTREE'].fields_by_name['message_id']._loaded_options = None
  _globals['_EVENTINSERTEDINTOTREE'].fields_by_name['message_id']._serialized_options = b'\310\336\037\000\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_EVENTINSERTEDINTOTREE'].fields_by_name['merkle_tree_hook_id']._loaded_options = None
  _globals['_EVENTINSERTEDINTOTREE'].fields_by_name['merkle_tree_hook_id']._serialized_options = b'\310\336\037\000\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_EVENTGASPAYMENT'].fields_by_name['message_id']._loaded_options = None
  _globals['_EVENTGASPAYMENT'].fields_by_name['message_id']._serialized_options = b'\310\336\037\000\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_EVENTGASPAYMENT'].fields_by_name['igp_id']._loaded_options = None
  _globals['_EVENTGASPAYMENT'].fields_by_name['igp_id']._serialized_options = b'\310\336\037\000\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_EVENTCREATENOOPHOOK'].fields_by_name['noop_hook_id']._loaded_options = None
  _globals['_EVENTCREATENOOPHOOK'].fields_by_name['noop_hook_id']._serialized_options = b'\310\336\037\000\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_EVENTCREATEIGP'].fields_by_name['igp_id']._loaded_options = None
  _globals['_EVENTCREATEIGP'].fields_by_name['igp_id']._serialized_options = b'\310\336\037\000\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_EVENTSETIGP'].fields_by_name['igp_id']._loaded_options = None
  _globals['_EVENTSETIGP'].fields_by_name['igp_id']._serialized_options = b'\310\336\037\000\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_EVENTSETDESTINATIONGASCONFIG'].fields_by_name['igp_id']._loaded_options = None
  _globals['_EVENTSETDESTINATIONGASCONFIG'].fields_by_name['igp_id']._serialized_options = b'\310\336\037\000\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_EVENTSETDESTINATIONGASCONFIG'].fields_by_name['gas_overhead']._loaded_options = None
  _globals['_EVENTSETDESTINATIONGASCONFIG'].fields_by_name['gas_overhead']._serialized_options = b'\310\336\037\000\332\336\037\025cosmossdk.io/math.Int'
  _globals['_EVENTSETDESTINATIONGASCONFIG'].fields_by_name['gas_price']._loaded_options = None
  _globals['_EVENTSETDESTINATIONGASCONFIG'].fields_by_name['gas_price']._serialized_options = b'\310\336\037\000\332\336\037\025cosmossdk.io/math.Int'
  _globals['_EVENTSETDESTINATIONGASCONFIG'].fields_by_name['token_exchange_rate']._loaded_options = None
  _globals['_EVENTSETDESTINATIONGASCONFIG'].fields_by_name['token_exchange_rate']._serialized_options = b'\310\336\037\000\332\336\037\025cosmossdk.io/math.Int'
  _globals['_EVENTCLAIMIGP'].fields_by_name['igp_id']._loaded_options = None
  _globals['_EVENTCLAIMIGP'].fields_by_name['igp_id']._serialized_options = b'\310\336\037\000\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_EVENTCREATEMERKLETREEHOOK']._serialized_start=104
  _globals['_EVENTCREATEMERKLETREEHOOK']._serialized_end=369
  _globals['_EVENTINSERTEDINTOTREE']._serialized_start=372
  _globals['_EVENTINSERTEDINTOTREE']._serialized_end=633
  _globals['_EVENTGASPAYMENT']._serialized_start=636
  _globals['_EVENTGASPAYMENT']._serialized_end=936
  _globals['_EVENTCREATENOOPHOOK']._serialized_start=939
  _globals['_EVENTCREATENOOPHOOK']._serialized_end=1085
  _globals['_EVENTCREATEIGP']._serialized_start=1088
  _globals['_EVENTCREATEIGP']._serialized_end=1240
  _globals['_EVENTSETIGP']._serialized_start=1243
  _globals['_EVENTSETIGP']._serialized_end=1446
  _globals['_EVENTSETDESTINATIONGASCONFIG']._serialized_start=1449
  _globals['_EVENTSETDESTINATIONGASCONFIG']._serialized_end=1835
  _globals['_EVENTCLAIMIGP']._serialized_start=1838
  _globals['_EVENTCLAIMIGP']._serialized_end=1991
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: hyperlane/core/post_dispatch/v1/genesis.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from hyperlane.core.post_dispatch.v1 import types_pb2 as hyperlane_dot_core_dot_post__dispatch_dot_v1_dot_types__pb2
from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-hyperlane/core/post_dispatch/v1/genesis.proto\x12\x1fhyperlane.core.post_dispatch.v1\x1a+hyperlane/core/post_dispatch/v1/types.proto\x1a\x14gogoproto/gogo.proto\"\x87\x03\n\x0cGenesisState\x12Q\n\x04igps\x18\x01 \x03(\x0b\x32\x37.hyperlane.core.post_dispatch.v1.InterchainGasPaymasterB\x04\xc8\xde\x1f\x00R\x04igps\x12q\n\x0figp_gas_configs\x18\x02 \x03(\x0b\x32\x43.hyperlane.core.post_dispatch.v1.GenesisDestinationGasConfigWrapperB\x04\xc8\xde\x1f\x00R\rigpGasConfigs\x12\x61\n\x11merkle_tree_hooks\x18\x03 \x03(\x0b\x32/.hyperlane.core.post_dispatch.v1.MerkleTreeHookB\x04\xc8\xde\x1f\x00R\x0fmerkleTreeHooks\x12N\n\nnoop_hooks\x18\x04 \x03(\x0b\x32).hyperlane.core.post_dispatch.v1.NoopHookB\x04\xc8\xde\x1f\x00R\tnoopHooks\"\xed\x01\n\"GenesisDestinationGasConfigWrapper\x12#\n\rremote_domain\x18\x01 \x01(\rR\x0cremoteDomain\x12I\n\ngas_oracle\x18\x02 \x01(\x0b\x32*.hyperlane.core.post_dispatch.v1.GasOracleR\tgasOracle\x12@\n\x0cgas_overhead\x18\x03 \x01(\tB\x1d\xc8\xde\x1f\x00\xda\xde\x1f\x15\x63osmossdk.io/math.IntR\x0bgasOverhead\x12\x15\n\x06igp_id\x18\x04 \x01(\x04R\x05igpIdB\x99\x02\n#com.hyperlane.core.post_dispatch.v1B\x0cGenesisProtoP\x01ZIgithub.com/bcp-innovations/hyperlane-cosmos/x/core/02_post_dispatch/types\xa2\x02\x03HCP\xaa\x02\x1eHyperlane.Core.PostDispatch.V1\xca\x02\x1eHyperlane\\Core\\PostDispatch\\V1\xe2\x02*Hyperlane\\Core\\PostDispatch\\V1\\GPBMetadata\xea\x02!Hyperlane::Core::PostDispatch::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'hyperlane.core.post_dispatch.v1.genesis_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n#com.hyperlane.core.post_dispatch.v1B\014GenesisProtoP\001ZIgithub.com/bcp-innovations/hyperlane-cosmos/x/core/02_post_dispatch/types\242\002\003HCP\252\002\036Hyperlane.Core.PostDispatch.V1\312\002\036Hyperlane\\Core\\PostDispatch\\V1\342\002*Hyperlane\\Core\\PostDispatch\\V1\\GPBMetadata\352\002!Hyperlane::Core::PostDispatch::V1'
  _globals['_GENESISSTATE'].fields_by_name['igps']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['igps']._serialized_options = b'\310\336\037\000'
  _globals['_GENESISSTATE'].fields_by_name['igp_gas_configs']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['igp_gas_configs']._serialized_options = b'\310\336\037\000'
  _globals['_GENESISSTATE'].fields_by_name['merkle_tree_hooks']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['merkle_tree_hooks']._serialized_options = b'\310\336\037\000'
  _globals['_GENESISSTATE'].fields_by_name['noop_hooks']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['noop_hooks']._serialized_options = b'\310\336\037\000'
  _globals['_GENESISDESTINATIONGASCONFIGWRAPPER'].fields_by_name['gas_overhead']._loaded_options = None
  _globals['_GENESISDESTINATIONGASCONFIGWRAPPER'].fields_by_name['gas_overhead']._serialized_options = b'\310\336\037\000\332\336\037\025cosmossdk.io/math.Int'
  _globals['_GENESISSTATE']._serialized_start=150
  _globals['_GENESISSTATE']._serialized_end=541
  _globals['_GENESISDESTINATIONGASCONFIGWRAPPER']._serialized_start=544
  _globals['_GENESISDESTINATIONGASCONFIGWRAPPER']._serialized_end=781
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/iam/v1/options.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1bgoogle/iam/v1/options.proto\x12\rgoogle.iam.v1\"L\n\x10GetPolicyOptions\x12\x38\n\x18requested_policy_version\x18\x01 \x01(\x05R\x16requestedPolicyVersionB\xa5\x01\n\x11\x63om.google.iam.v1B\x0cOptionsProtoP\x01Z)cloud.google.com/go/iam/apiv1/iampb;iampb\xf8\x01\x01\xa2\x02\x03GIX\xaa\x02\rGoogle.Iam.V1\xca\x02\rGoogle\\Iam\\V1\xe2\x02\x19Google\\Iam\\V1\\GPBMetadata\xea\x02\x0fGoogle::Iam::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'google.iam.v1.options_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\021com.google.iam.v1B\014OptionsProtoP\001Z)cloud.google.com/go/iam/apiv1/iampb;iampb\370\001\001\242\002\003GIX\252\002\rGoogle.Iam.V1\312\002\rGoogle\\Iam\\V1\342\002\031Google\\Iam\\V1\\GPBMetadata\352\002\017Google::Iam::V1'
  _globals['_GETPOLICYOPTIONS']._serialized_start=46
  _globals['_GETPOLICYOPTIONS']._serialized_end=122
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: exchange/injective_rfqrpc.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1f\x65xchange/injective_rfqrpc.proto\x12\x10injective_rfqrpc\"L\n\x0eRequestRequest\x12:\n\x07request\x18\x01 \x01(\x0b\x32 .injective_rfqrpc.RFQRequestTypeR\x07request\"\x91\x03\n\x0eRFQRequestType\x12\x15\n\x06rfq_id\x18\x01 \x01(\x04R\x05rfqId\x12\x1b\n\tmarket_id\x18\x02 \x01(\tR\x08marketId\x12\x1c\n\tdirection\x18\x03 \x01(\tR\tdirection\x12\x16\n\x06margin\x18\x04 \x01(\tR\x06margin\x12\x1a\n\x08quantity\x18\x05 \x01(\tR\x08quantity\x12\x1f\n\x0bworst_price\x18\x06 \x01(\tR\nworstPrice\x12\'\n\x0frequest_address\x18\x07 \x01(\tR\x0erequestAddress\x12\x16\n\x06\x65xpiry\x18\x08 \x01(\x04R\x06\x65xpiry\x12\x16\n\x06status\x18\t \x01(\tR\x06status\x12\x1d\n\ncreated_at\x18\n \x01(\x12R\tcreatedAt\x12\x1d\n\nupdated_at\x18\x0b \x01(\x12R\tupdatedAt\x12)\n\x10transaction_time\x18\x0c \x01(\x04R\x0ftransactionTime\x12\x16\n\x06height\x18\r \x01(\x04R\x06height\")\n\x0fRequestResponse\x12\x16\n\x06status\x18\x01 \x01(\tR\x06status\"5\n\x14StreamRequestRequest\x12\x1d\n\nmarket_ids\x18\x01 \x03(\tR\tmarketIds\"~\n\x15StreamRequestResponse\x12:\n\x07request\x18\x01 \x01(\x0b\x32 .injective_rfqrpc.RFQRequestTypeR\x07request\x12)\n\x10stream_operation\x18\x02 \x01(\tR\x0fstreamOperation\"D\n\x0cQuoteRequest\x12\x34\n\x05quote\x18\x01 \x01(\x0b\x32\x1e.injective_rfqrpc.RFQQuoteTypeR\x05quote\"\x95\x04\n\x0cRFQQuoteType\x12\x19\n\x08\x63hain_id\x18\x01 \x01(\tR\x07\x63hainId\x12)\n\x10\x63ontract_address\x18\x02 \x01(\tR\x0f\x63ontractAddress\x12\x1b\n\tmarket_id\x18\x03 \x01(\tR\x08marketId\x12\x15\n\x06rfq_id\x18\x04 \x01(\x04R\x05rfqId\x12\'\n\x0ftaker_direction\x18\x05 \x01(\tR\x0etakerDirection\x12\x16\n\x06margin\x18\x06 \x01(\tR\x06margin\x12\x1a\n\x08quantity\x18\x07 \x01(\tR\x08quantity\x12\x14\n\x05price\x18\x08 \x01(\tR\x05price\x12\x16\n\x06\x65xpiry\x18\t \x01(\x04R\x06\x65xpiry\x12\x14\n\x05maker\x18\n \x01(\tR\x05maker\x12\x14\n\x05taker\x18\x0b \x01(\tR\x05taker\x12\x1c\n\tsignature\x18\x0c \x01(\tR\tsignature\x12\x16\n\x06status\x18\r \x01(\tR\x06status\x12\x1d\n\ncreated_at\x18\x0e \x01(\x12R\tcreatedAt\x12\x1d\n\nupdated_at\x18\x0f \x01(\x12R\tupdatedAt\x12\x16\n\x06height\x18\x10 \x01(\x04R\x06height\x12\x1d\n\nevent_time\x18\x11 \x01(\x04R\teventTime\x12)\n\x10transaction_time\x18\x12 \x01(\x04R\x0ftransactionTime\"\'\n\rQuoteResponse\x12\x16\n\x06status\x18\x01 \x01(\tR\x06status\"2\n\x12StreamQuoteRequest\x12\x1c\n\taddresses\x18\x01 \x03(\tR\taddresses\"v\n\x13StreamQuoteResponse\x12\x34\n\x05quote\x18\x01 \x01(\x0b\x32\x1e.injective_rfqrpc.RFQQuoteTypeR\x05quote\x12)\n\x10stream_operation\x18\x02 \x01(\tR\x0fstreamOperation\"\x18\n\x16GetOpenRequestsRequest\"W\n\x17GetOpenRequestsResponse\x12<\n\x08requests\x18\x01 \x03(\x0b\x32 .injective_rfqrpc.RFQRequestTypeR\x08requests\"\x19\n\x17GetPendingQuotesRequest\"R\n\x18GetPendingQuotesResponse\x12\x36\n\x06quotes\x18\x01 \x03(\x0b\x32\x1e.injective_rfqrpc.RFQQuoteTypeR\x06quotes\"_\n\x15ListSettlementRequest\x12\x1c\n\taddresses\x18\x01 \x03(\tR\taddresses\x12\x12\n\x04skip\x18\x02 \x01(\x12R\x04skip\x12\x14\n\x05limit\x18\x03 \x01(\x12R\x05limit\"u\n\x16ListSettlementResponse\x12\x45\n\x0bsettlements\x18\x01 \x03(\x0b\x32#.injective_rfqrpc.RFQSettlementTypeR\x0bsettlements\x12\x14\n\x05total\x18\x02 \x01(\x12R\x05total\"\xa2\x04\n\x11RFQSettlementType\x12\x15\n\x06rfq_id\x18\x01 \x01(\x04R\x05rfqId\x12\x1b\n\tmarket_id\x18\x02 \x01(\tR\x08marketId\x12\x14\n\x05taker\x18\x03 \x01(\tR\x05taker\x12\x1c\n\tdirection\x18\x04 \x01(\tR\tdirection\x12\x16\n\x06margin\x18\x05 \x01(\tR\x06margin\x12\x1a\n\x08quantity\x18\x06 \x01(\tR\x08quantity\x12\x1f\n\x0bworst_price\x18\x07 \x01(\tR\nworstPrice\x12Z\n\x0funfilled_action\x18\x08 \x01(\x0b\x32\x31.injective_rfqrpc.RFQSettlementUnfilledActionTypeR\x0eunfilledAction\x12+\n\x11\x66\x61llback_quantity\x18\t \x01(\tR\x10\x66\x61llbackQuantity\x12\'\n\x0f\x66\x61llback_margin\x18\n \x01(\tR\x0e\x66\x61llbackMargin\x12)\n\x10transaction_time\x18\x0b \x01(\x04R\x0ftransactionTime\x12\x1d\n\ncreated_at\x18\x0c \x01(\x12R\tcreatedAt\x12\x1d\n\nupdated_at\x18\r \x01(\x12R\tupdatedAt\x12\x1d\n\nevent_time\x18\x0e \x01(\x04R\teventTime\x12\x16\n\x06height\x18\x0f \x01(\x04R\x06height\"\xb0\x01\n\x1fRFQSettlementUnfilledActionType\x12\x44\n\x05limit\x18\x01 \x01(\x0b\x32..injective_rfqrpc.RFQSettlementLimitActionTypeR\x05limit\x12G\n\x06market\x18\x02 \x01(\x0b\x32/.injective_rfqrpc.RFQSettlementMarketActionTypeR\x06market\"4\n\x1cRFQSettlementLimitActionType\x12\x14\n\x05price\x18\x01 \x01(\tR\x05price\"\x1f\n\x1dRFQSettlementMarketActionType\"7\n\x17StreamSettlementRequest\x12\x1c\n\taddresses\x18\x01 \x03(\tR\taddresses\"\x8a\x01\n\x18StreamSettlementResponse\x12\x43\n\nsettlement\x18\x01 \x01(\x0b\x32#.injective_rfqrpc.RFQSettlementTypeR\nsettlement\x12)\n\x10stream_operation\x18\x02 \x01(\tR\x0fstreamOperation\"\x82\x01\n\x1bTakerStreamStreamingRequest\x12!\n\x0cmessage_type\x18\x01 \x01(\tR\x0bmessageType\x12@\n\x07request\x18\x02 \x01(\x0b\x32&.injective_rfqrpc.CreateRFQRequestTypeR\x07request\"\xee\x02\n\x14\x43reateRFQRequestType\x12\x15\n\x06rfq_id\x18\x01 \x01(\x04R\x05rfqId\x12\x1b\n\tmarket_id\x18\x02 \x01(\tR\x08marketId\x12\x1c\n\tdirection\x18\x03 \x01(\tR\tdirection\x12\x16\n\x06margin\x18\x04 \x01(\tR\x06margin\x12\x1a\n\x08quantity\x18\x05 \x01(\tR\x08quantity\x12\x1f\n\x0bworst_price\x18\x06 \x01(\tR\nworstPrice\x12\x16\n\x06\x65xpiry\x18\x07 \x01(\x04R\x06\x65xpiry\x12\x16\n\x06status\x18\x08 \x01(\tR\x06status\x12\x1d\n\ncreated_at\x18\t \x01(\x12R\tcreatedAt\x12\x1d\n\nupdated_at\x18\n \x01(\x12R\tupdatedAt\x12)\n\x10transaction_time\x18\x0b \x01(\x04R\x0ftransactionTime\x12\x16\n\x06height\x18\x0c \x01(\x04R\x06height\"\xe1\x01\n\x13TakerStreamResponse\x12!\n\x0cmessage_type\x18\x01 \x01(\tR\x0bmessageType\x12\x34\n\x05quote\x18\x02 \x01(\x0b\x32\x1e.injective_rfqrpc.RFQQuoteTypeR\x05quote\x12<\n\x0brequest_ack\x18\x03 \x01(\x0b\x32\x1b.injective_rfqrpc.StreamAckR\nrequestAck\x12\x33\n\x05\x65rror\x18\x04 \x01(\x0b\x32\x1d.injective_rfqrpc.StreamErrorR\x05\x65rror\":\n\tStreamAck\x12\x15\n\x06rfq_id\x18\x01 \x01(\x04R\x05rfqId\x12\x16\n\x06status\x18\x02 \x01(\tR\x06status\"<\n\x0bStreamError\x12\x12\n\x04\x63ode\x18\x01 \x01(\tR\x04\x63ode\x12\x19\n\x08message_\x18\x02 \x01(\tR\x07message\"v\n\x1bMakerStreamStreamingRequest\x12!\n\x0cmessage_type\x18\x01 \x01(\tR\x0bmessageType\x12\x34\n\x05quote\x18\x02 \x01(\x0b\x32\x1e.injective_rfqrpc.RFQQuoteTypeR\x05quote\"\xe3\x01\n\x13MakerStreamResponse\x12!\n\x0cmessage_type\x18\x01 \x01(\tR\x0bmessageType\x12:\n\x07request\x18\x02 \x01(\x0b\x32 .injective_rfqrpc.RFQRequestTypeR\x07request\x12\x38\n\tquote_ack\x18\x03 \x01(\x0b\x32\x1b.injective_rfqrpc.StreamAckR\x08quoteAck\x12\x33\n\x05\x65rror\x18\x04 \x01(\x0b\x32\x1d.injective_rfqrpc.StreamErrorR\x05\x65rror2\xe4\x07\n\x0fInjectiveRFQRPC\x12N\n\x07Request\x12 .injective_rfqrpc.RequestRequest\x1a!.injective_rfqrpc.RequestResponse\x12\x62\n\rStreamRequest\x12&.injective_rfqrpc.StreamRequestRequest\x1a\'.injective_rfqrpc.StreamRequestResponse0\x01\x12H\n\x05Quote\x12\x1e.injective_rfqrpc.QuoteRequest\x1a\x1f.injective_rfqrpc.QuoteResponse\x12\\\n\x0bStreamQuote\x12$.injective_rfqrpc.StreamQuoteRequest\x1a%.injective_rfqrpc.StreamQuoteResponse0\x01\x12\x66\n\x0fGetOpenRequests\x12(.injective_rfqrpc.GetOpenRequestsRequest\x1a).injective_rfqrpc.GetOpenRequestsResponse\x12i\n\x10GetPendingQuotes\x12).injective_rfqrpc.GetPendingQuotesRequest\x1a*.injective_rfqrpc.GetPendingQuotesResponse\x12\x63\n\x0eListSettlement\x12\'.injective_rfqrpc.ListSettlementRequest\x1a(.injective_rfqrpc.ListSettlementResponse\x12k\n\x10StreamSettlement\x12).injective_rfqrpc.StreamSettlementRequest\x1a*.injective_rfqrpc.StreamSettlementResponse0\x01\x12g\n\x0bTakerStream\x12-.injective_rfqrpc.TakerStreamStreamingRequest\x1a%.injective_rfqrpc.TakerStreamResponse(\x01\x30\x01\x12g\n\x0bMakerStream\x12-.injective_rfqrpc.MakerStreamStreamingRequest\x1a%.injective_rfqrpc.MakerStreamResponse(\x01\x30\x01\x42\x9d\x01\n\x14\x63om.injective_rfqrpcB\x14InjectiveRfqrpcProtoP\x01Z\x13/injective_rfqrpcpb\xa2\x02\x03IXX\xaa\x02\x0fInjectiveRfqrpc\xca\x02\x0fInjectiveRfqrpc\xe2\x02\x1bInjectiveRfqrpc\\GPBMetadata\xea\x02\x0fInjectiveRfqrpcb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'exchange.injective_rfqrpc_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\024com.injective_rfqrpcB\024InjectiveRfqrpcProtoP\001Z\023/injective_rfqrpcpb\242\002\003IXX\252\002\017InjectiveRfqrpc\312\002\017InjectiveRfqrpc\342\002\033InjectiveRfqrpc\\GPBMetadata\352\002\017InjectiveRfqrpc'
  _globals['_REQUESTREQUEST']._serialized_start=53
  _globals['_REQUESTREQUEST']._serialized_end=129
  _globals['_RFQREQUESTTYPE']._serialized_start=132
  _globals['_RFQREQUESTTYPE']._serialized_end=533
  _globals['_REQUESTRESPONSE']._serialized_start=535
  _globals['_REQUESTRESPONSE']._serialized_end=576
  _globals['_STREAMREQUESTREQUEST']._serialized_start=578
  _globals['_STREAMREQUESTREQUEST']._serialized_end=631
  _globals['_STREAMREQUESTRESPONSE']._serialized_start=633
  _globals['_STREAMREQUESTRESPONSE']._serialized_end=759
  _globals['_QUOTEREQUEST']._serialized_start=761
  _globals['_QUOTEREQUEST']._serialized_end=829
  _globals['_RFQQUOTETYPE']._serialized_start=832
  _globals['_RFQQUOTETYPE']._serialized_end=1365
  _globals['_QUOTERESPONSE']._serialized_start=1367
  _globals['_QUOTERESPONSE']._serialized_end=1406
  _globals['_STREAMQUOTEREQUEST']._serialized_start=1408
  _globals['_STREAMQUOTEREQUEST']._serialized_end=1458
  _globals['_STREAMQUOTERESPONSE']._serialized_start=1460
  _globals['_STREAMQUOTERESPONSE']._serialized_end=1578
  _globals['_GETOPENREQUESTSREQUEST']._serialized_start=1580
  _globals['_GETOPENREQUESTSREQUEST']._serialized_end=1604
  _globals['_GETOPENREQUESTSRESPONSE']._serialized_start=1606
  _globals['_GETOPENREQUESTSRESPONSE']._serialized_end=1693
  _globals['_GETPENDINGQUOTESREQUEST']._serialized_start=1695
  _globals['_GETPENDINGQUOTESREQUEST']._serialized_end=1720
  _globals['_GETPENDINGQUOTESRESPONSE']._serialized_start=1722
  _globals['_GETPENDINGQUOTESRESPONSE']._serialized_end=1804
  _globals['_LISTSETTLEMENTREQUEST']._serialized_start=1806
  _globals['_LISTSETTLEMENTREQUEST']._serialized_end=1901
  _globals['_LISTSETTLEMENTRESPONSE']._serialized_start=1903
  _globals['_LISTSETTLEMENTRESPONSE']._serialized_end=2020
  _globals['_RFQSETTLEMENTTYPE']._serialized_start=2023
  _globals['_RFQSETTLEMENTTYPE']._serialized_end=2569
  _globals['_RFQSETTLEMENTUNFILLEDACTIONTYPE']._serialized_start=2572
  _globals['_RFQSETTLEMENTUNFILLEDACTIONTYPE']._serialized_end=2748
  _globals['_RFQSETTLEMENTLIMITACTIONTYPE']._serialized_start=2750
  _globals['_RFQSETTLEMENTLIMITACTIONTYPE']._serialized_end=2802
  _globals['_RFQSETTLEMENTMARKETACTIONTYPE']._serialized_start=2804
  _globals['_RFQSETTLEMENTMARKETACTIONTYPE']._serialized_end=2835
  _globals['_STREAMSETTLEMENTREQUEST']._serialized_start=2837
  _globals['_STREAMSETTLEMENTREQUEST']._serialized_end=2892
  _globals['_STREAMSETTLEMENTRESPONSE']._serialized_start=2895
  _globals['_STREAMSETTLEMENTRESPONSE']._serialized_end=3033
  _globals['_TAKERSTREAMSTREAMINGREQUEST']._serialized_start=3036
  _globals['_TAKERSTREAMSTREAMINGREQUEST']._serialized_end=3166
  _globals['_CREATERFQREQUESTTYPE']._serialized_start=3169
  _globals['_CREATERFQREQUESTTYPE']._serialized_end=3535
  _globals['_TAKERSTREAMRESPONSE']._serialized_start=3538
  _globals['_TAKERSTREAMRESPONSE']._serialized_end=3763
  _globals['_STREAMACK']._serialized_start=3765
  _globals['_STREAMACK']._serialized_end=3823
  _globals['_STREAMERROR']._serialized_start=3825
  _globals['_STREAMERROR']._serialized_end=3885
  _globals['_MAKERSTREAMSTREAMINGREQUEST']._serialized_start=3887
  _globals['_MAKERSTREAMSTREAMINGREQUEST']._serialized_end=4005
  _globals['_MAKERSTREAMRESPONSE']._serialized_start=4008
  _globals['_MAKERSTREAMRESPONSE']._serialized_end=4235
  _globals['_INJECTIVERFQRPC']._serialized_start=4238
  _globals['_INJECTIVERFQRPC']._serialized_end=5234
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from pyinjective.proto.exchange import injective_rfqrpc_pb2 as exchange_dot_injective__rfqrpc__pb2


class InjectiveRFQRPCStub(object):
    """InjectiveRFQRPC defines gRPC API of the RFQ (Request for Quote) API.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Request = channel.unary_unary(
                '/injective_rfqrpc.InjectiveRFQRPC/Request',
                request_serializer=exchange_dot_injective__rfqrpc__pb2.RequestRequest.SerializeToString,
                response_deserializer=exchange_dot_injective__rfqrpc__pb2.RequestResponse.FromString,
                _registered_method=True)
        self.StreamRequest = channel.unary_stream(
                '/injective_rfqrpc.InjectiveRFQRPC/StreamRequest',
                request_serializer=exchange_dot_injective__rfqrpc__pb2.StreamRequestRequest.SerializeToString,
                response_deserializer=exchange_dot_injective__rfqrpc__pb2.StreamRequestResponse.FromString,
                _registered_method=True)
        self.Quote = channel.unary_unary(
                '/injective_rfqrpc.InjectiveRFQRPC/Quote',
                request_serializer=exchange_dot_injective__rfqrpc__pb2.QuoteRequest.SerializeToString,
                response_deserializer=exchange_dot_injective__rfqrpc__pb2.QuoteResponse.FromString,
                _registered_method=True)
        self.StreamQuote = channel.unary_stream(
                '/injective_rfqrpc.InjectiveRFQRPC/StreamQuote',
                request_serializer=exchange_dot_injective__rfqrpc__pb2.StreamQuoteRequest.SerializeToString,
                response_deserializer=exchange_dot_injective__rfqrpc__pb2.StreamQuoteResponse.FromString,
                _registered_method=True)
        self.GetOpenRequests = channel.unary_unary(
                '/injective_rfqrpc.InjectiveRFQRPC/GetOpenRequests',
                request_serializer=exchange_dot_injective__rfqrpc__pb2.GetOpenRequestsRequest.SerializeToString,
                response_deserializer=exchange_dot_injective__rfqrpc__pb2.GetOpenRequestsResponse.FromString,
                _registered_method=True)
        self.GetPendingQuotes = channel.unary_unary(
                '/injective_rfqrpc.InjectiveRFQRPC/GetPendingQuotes',
                request_serializer=exchange_dot_injective__rfqrpc__pb2.GetPendingQuotesRequest.SerializeToString,
                response_deserializer=exchange_dot_injective__rfqrpc__pb2.GetPendingQuotesResponse.FromString,
                _registered_method=True)
        self.ListSettlement = channel.unary_unary(
                '/injective_rfqrpc.InjectiveRFQRPC/ListSettlement',
                request_serializer=exchange_dot_injective__rfqrpc__pb2.ListSettlementRequest.SerializeToString,
                response_deserializer=exchange_dot_injective__rfqrpc__pb2.ListSettlementResponse.FromString,
                _registered_method=True)
        self.StreamSettlement = channel.unary_stream(
                '/injective_rfqrpc.InjectiveRFQRPC/StreamSettlement',
                request_serializer=exchange_dot_injective__rfqrpc__pb2.StreamSettlementRequest.SerializeToString,
                response_deserializer=exchange_dot_injective__rfqrpc__pb2.StreamSettlementResponse.FromString,
                _registered_method=True)
        self.TakerStream = channel.stream_stream(
                '/injective_rfqrpc.InjectiveRFQRPC/TakerStream',
                request_serializer=exchange_dot_injective__rfqrpc__pb2.TakerStreamStreamingRequest.SerializeToString,
                response_deserializer=exchange_dot_injective__rfqrpc__pb2.TakerStreamResponse.FromString,
                _registered_method=True)
        self.MakerStream = channel.stream_stream(
                '/injective_rfqrpc.InjectiveRFQRPC/MakerStream',
                request_serializer=exchange_dot_injective__rfqrpc__pb2.MakerStreamStreamingRequest.SerializeToString,
                response_deserializer=exchange_dot_injective__rfqrpc__pb2.MakerStreamResponse.FromString,
                _registered_method=True)


class InjectiveRFQRPCServicer(object):
    """InjectiveRFQRPC defines gRPC API of the RFQ (Request for Quote) API.
    """

    def Request(self, request, context):
        """Create RFQ request
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StreamRequest(self, request, context):
        """Stream RFQ requests
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Quote(self, request, context):
        """Create RFQ quote
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StreamQuote(self, request, context):
        """Stream RFQ quotes
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetOpenRequests(self, request, context):
        """Get open RFQ requests
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetPendingQuotes(self, request, context):
        """Get pending RFQ quotes
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListSettlement(self, request, context):
        """List RFQ settlements
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StreamSettlement(self, request, context):
        """Stream RFQ settlements
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TakerStream(self, request_iterator, context):
        """Bidirectional stream for takers: send requests, receive quotes
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def MakerStream(self, request_iterator, context):
        """Bidirectional stream for makers: receive requests, send quotes
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_InjectiveRFQRPCServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Request': grpc.unary_unary_rpc_method_handler(
                    servicer.Request,
                    request_deserializer=exchange_dot_injective__rfqrpc__pb2.RequestRequest.FromString,
                    response_serializer=exchange_dot_injective__rfqrpc__pb2.RequestResponse.SerializeToString,
            ),
            'StreamRequest': grpc.unary_stream_rpc_method_handler(
                    servicer.StreamRequest,
                    request_deserializer=exchange_dot_injective__rfqrpc__pb2.StreamRequestRequest.FromString,
                    response_serializer=exchange_dot_injective__rfqrpc__pb2.StreamRequestResponse.SerializeToString,
            ),
            'Quote': grpc.unary_unary_rpc_method_handler(
                    servicer.Quote,
                    request_deserializer=exchange_dot_injective__rfqrpc__pb2.QuoteRequest.FromString,
                    response_serializer=exchange_dot_injective__rfqrpc__pb2.QuoteResponse.SerializeToString,
            ),
            'StreamQuote': grpc.unary_stream_rpc_method_handler(
                    servicer.StreamQuote,
                    request_deserializer=exchange_dot_injective__rfqrpc__pb2.StreamQuoteRequest.FromString,
                    response_serializer=exchange_dot_injective__rfqrpc__pb2.StreamQuoteResponse.SerializeToString,
            ),
            'GetOpenRequests': grpc.unary_unary_rpc_method_handler(
                    servicer.GetOpenRequests,
                    request_deserializer=exchange_dot_injective__rfqrpc__pb2.GetOpenRequestsRequest.FromString,
                    response_serializer=exchange_dot_injective__rfqrpc__pb2.GetOpenRequestsResponse.SerializeToString,
            ),
            'GetPendingQuotes': grpc.unary_unary_rpc_method_handler(
                    servicer.GetPendingQuotes,
                    request_deserializer=exchange_dot_injective__rfqrpc__pb2.GetPendingQuotesRequest.FromString,
                    response_serializer=exchange_dot_injective__rfqrpc__pb2.GetPendingQuotesResponse.SerializeToString,
            ),
            'ListSettlement': grpc.unary_unary_rpc_method_handler(
                    servicer.ListSettlement,
                    request_deserializer=exchange_dot_injective__rfqrpc__pb2.ListSettlementRequest.FromString,
                    response_serializer=exchange_dot_injective__rfqrpc__pb2.ListSettlementResponse.SerializeToString,
            ),
            'StreamSettlement': grpc.unary_stream_rpc_method_handler(
                    servicer.StreamSettlement,
                    request_deserializer=exchange_dot_injective__rfqrpc__pb2.StreamSettlementRequest.FromString,
                    response_serializer=exchange_dot_injective__rfqrpc__pb2.StreamSettlementResponse.SerializeToString,
            ),
            'TakerStream': grpc.stream_stream_rpc_method_handler(
                    servicer.TakerStream,
                    request_deserializer=exchange_dot_injective__rfqrpc__pb2.TakerStreamStreamingRequest.FromString,
                    response_serializer=exchange_dot_injective__rfqrpc__pb2.TakerStreamResponse.SerializeToString,
            ),
            'MakerStream': grpc.stream_stream_rpc_method_handler(
                    servicer.MakerStream,
                    request_deserializer=exchange_dot_injective__rfqrpc__pb2.MakerStreamStreamingRequest.FromString,
                    response_serializer=exchange_dot_injective__rfqrpc__pb2.MakerStreamResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'injective_rfqrpc.InjectiveRFQRPC', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('injective_rfqrpc.InjectiveRFQRPC', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class InjectiveRFQRPC(object):
    """InjectiveRFQRPC defines gRPC API of the RFQ (Request for Quote) API.
    """

    @staticmethod
    def Request(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/injective_rfqrpc.InjectiveRFQRPC/Request',
            exchange_dot_injective__rfqrpc__pb2.RequestRequest.SerializeToString,
            exchange_dot_injective__rfqrpc__pb2.RequestResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def StreamRequest(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/injective_rfqrpc.InjectiveRFQRPC/StreamRequest',
            exchange_dot_injective__rfqrpc__pb2.StreamRequestRequest.SerializeToString,
            exchange_dot_injective__rfqrpc__pb2.StreamRequestResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Quote(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/injective_rfqrpc.InjectiveRFQRPC/Quote',
            exchange_dot_injective__rfqrpc__pb2.QuoteRequest.SerializeToString,
            exchange_dot_injective__rfqrpc__pb2.QuoteResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def StreamQuote(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/injective_rfqrpc.InjectiveRFQRPC/StreamQuote',
            exchange_dot_injective__rfqrpc__pb2.StreamQuoteRequest.SerializeToString,
            exchange_dot_injective__rfqrpc__pb2.StreamQuoteResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetOpenRequests(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/injective_rfqrpc.InjectiveRFQRPC/GetOpenRequests',
            exchange_dot_injective__rfqrpc__pb2.GetOpenRequestsRequest.SerializeToString,
            exchange_dot_injective__rfqrpc__pb2.GetOpenRequestsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetPendingQuotes(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/injective_rfqrpc.InjectiveRFQRPC/GetPendingQuotes',
            exchange_dot_injective__rfqrpc__pb2.GetPendingQuotesRequest.SerializeToString,
            exchange_dot_injective__rfqrpc__pb2.GetPendingQuotesResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListSettlement(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/injective_rfqrpc.InjectiveRFQRPC/ListSettlement',
            exchange_dot_injective__rfqrpc__pb2.ListSettlementRequest.SerializeToString,
            exchange_dot_injective__rfqrpc__pb2.ListSettlementResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def StreamSettlement(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/injective_rfqrpc.InjectiveRFQRPC/StreamSettlement',
            exchange_dot_injective__rfqrpc__pb2.StreamSettlementRequest.SerializeToString,
            exchange_dot_injective__rfqrpc__pb2.StreamSettlementResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def TakerStream(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_stream(
            request_iterator,
            target,
            '/injective_rfqrpc.InjectiveRFQRPC/TakerStream',
            exchange_dot_injective__rfqrpc__pb2.TakerStreamStreamingRequest.SerializeToString,
            exchange_dot_injective__rfqrpc__pb2.TakerStreamResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def MakerStream(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_stream(
            request_iterator,
            target,
            '/injective_rfqrpc.InjectiveRFQRPC/MakerStream',
            exchange_dot_injective__rfqrpc__pb2.MakerStreamStreamingRequest.SerializeToString,
            exchange_dot_injective__rfqrpc__pb2.MakerStreamResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: hyperlane/core/interchain_security/v1/tx.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from pyinjective.proto.cosmos.msg.v1 import msg_pb2 as cosmos_dot_msg_dot_v1_dot_msg__pb2
from pyinjective.proto.amino import amino_pb2 as amino_dot_amino__pb2
from hyperlane.core.interchain_security.v1 import types_pb2 as hyperlane_dot_core_dot_interchain__security_dot_v1_dot_types__pb2
from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n.hyperlane/core/interchain_security/v1/tx.proto\x12%hyperlane.core.interchain_security.v1\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x17\x63osmos/msg/v1/msg.proto\x1a\x11\x61mino/amino.proto\x1a\x31hyperlane/core/interchain_security/v1/types.proto\x1a\x14gogoproto/gogo.proto\"\xb4\x01\n\x1dMsgCreateMessageIdMultisigIsm\x12\x18\n\x07\x63reator\x18\x01 \x01(\tR\x07\x63reator\x12\x1e\n\nvalidators\x18\x02 \x03(\tR\nvalidators\x12\x1c\n\tthreshold\x18\x03 \x01(\rR\tthreshold:;\x82\xe7\xb0*\x07\x63reator\x8a\xe7\xb0**hyperlane/v1/MsgCreateMessageIdMultisigIsm\"|\n%MsgCreateMessageIdMultisigIsmResponse\x12S\n\x02id\x18\x01 \x01(\tBC\xc8\xde\x1f\x00\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\x02id\"\xb6\x01\n\x1eMsgCreateMerkleRootMultisigIsm\x12\x18\n\x07\x63reator\x18\x01 \x01(\tR\x07\x63reator\x12\x1e\n\nvalidators\x18\x02 \x03(\tR\nvalidators\x12\x1c\n\tthreshold\x18\x03 \x01(\rR\tthreshold:<\x82\xe7\xb0*\x07\x63reator\x8a\xe7\xb0*+hyperlane/v1/MsgCreateMerkleRootMultisigIsm\"}\n&MsgCreateMerkleRootMultisigIsmResponse\x12S\n\x02id\x18\x01 \x01(\tBC\xc8\xde\x1f\x00\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\x02id\"\\\n\x10MsgCreateNoopIsm\x12\x18\n\x07\x63reator\x18\x01 \x01(\tR\x07\x63reator:.\x82\xe7\xb0*\x07\x63reator\x8a\xe7\xb0*\x1dhyperlane/v1/MsgCreateNoopIsm\"o\n\x18MsgCreateNoopIsmResponse\x12S\n\x02id\x18\x01 \x01(\tBC\xc8\xde\x1f\x00\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\x02id\"\xaf\x02\n\x14MsgAnnounceValidator\x12\x1c\n\tvalidator\x18\x01 \x01(\tR\tvalidator\x12)\n\x10storage_location\x18\x02 \x01(\tR\x0fstorageLocation\x12\x1c\n\tsignature\x18\x03 \x01(\tR\tsignature\x12\x62\n\nmailbox_id\x18\x04 \x01(\tBC\xc8\xde\x1f\x00\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\tmailboxId\x12\x18\n\x07\x63reator\x18\x05 \x01(\tR\x07\x63reator:2\x82\xe7\xb0*\x07\x63reator\x8a\xe7\xb0*!hyperlane/v1/MsgAnnounceValidator\"\x1e\n\x1cMsgAnnounceValidatorResponse\"\xae\x01\n\x13MsgCreateRoutingIsm\x12\x18\n\x07\x63reator\x18\x01 \x01(\tR\x07\x63reator\x12J\n\x06routes\x18\x02 \x03(\x0b\x32,.hyperlane.core.interchain_security.v1.RouteB\x04\xc8\xde\x1f\x00R\x06routes:1\x82\xe7\xb0*\x07\x63reator\x8a\xe7\xb0* hyperlane/v1/MsgCreateRoutingIsm\"r\n\x1bMsgCreateRoutingIsmResponse\x12S\n\x02id\x18\x01 \x01(\tBC\xc8\xde\x1f\x00\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\x02id\"\x9b\x02\n\x16MsgSetRoutingIsmDomain\x12Z\n\x06ism_id\x18\x01 \x01(\tBC\xc8\xde\x1f\x00\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\x05ismId\x12H\n\x05route\x18\x02 \x01(\x0b\x32,.hyperlane.core.interchain_security.v1.RouteB\x04\xc8\xde\x1f\x00R\x05route\x12\x14\n\x05owner\x18\x03 \x01(\tR\x05owner:E\x82\xe7\xb0*\x05owner\x8a\xe7\xb0*6hyperlane/v1/MsgCreateRoMsgSetRoutingIsmDomainutingIsm\" \n\x1eMsgSetRoutingIsmDomainResponse\"\xdc\x01\n\x19MsgRemoveRoutingIsmDomain\x12Z\n\x06ism_id\x18\x01 \x01(\tBC\xc8\xde\x1f\x00\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\x05ismId\x12\x16\n\x06\x64omain\x18\x02 \x01(\rR\x06\x64omain\x12\x14\n\x05owner\x18\x03 \x01(\tR\x05owner:5\x82\xe7\xb0*\x05owner\x8a\xe7\xb0*&hyperlane/v1/MsgRemoveRoutingIsmDomain\"#\n!MsgRemoveRoutingIsmDomainResponse\"\xa8\x02\n\x18MsgUpdateRoutingIsmOwner\x12Z\n\x06ism_id\x18\x01 \x01(\tBC\xc8\xde\x1f\x00\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\x05ismId\x12\x14\n\x05owner\x18\x02 \x01(\tR\x05owner\x12\x35\n\tnew_owner\x18\x03 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\x08newOwner\x12-\n\x12renounce_ownership\x18\x04 \x01(\x08R\x11renounceOwnership:4\x82\xe7\xb0*\x05owner\x8a\xe7\xb0*%hyperlane/v1/MsgUpdateRoutingIsmOwner\"\"\n MsgUpdateRoutingIsmOwnerResponse2\x97\n\n\x03Msg\x12\xb0\x01\n\x1a\x43reateMessageIdMultisigIsm\x12\x44.hyperlane.core.interchain_security.v1.MsgCreateMessageIdMultisigIsm\x1aL.hyperlane.core.interchain_security.v1.MsgCreateMessageIdMultisigIsmResponse\x12\xb3\x01\n\x1b\x43reateMerkleRootMultisigIsm\x12\x45.hyperlane.core.interchain_security.v1.MsgCreateMerkleRootMultisigIsm\x1aM.hyperlane.core.interchain_security.v1.MsgCreateMerkleRootMultisigIsmResponse\x12\x89\x01\n\rCreateNoopIsm\x12\x37.hyperlane.core.interchain_security.v1.MsgCreateNoopIsm\x1a?.hyperlane.core.interchain_security.v1.MsgCreateNoopIsmResponse\x12\x92\x01\n\x10\x43reateRoutingIsm\x12:.hyperlane.core.interchain_security.v1.MsgCreateRoutingIsm\x1a\x42.hyperlane.core.interchain_security.v1.MsgCreateRoutingIsmResponse\x12\x9b\x01\n\x13SetRoutingIsmDomain\x12=.hyperlane.core.interchain_security.v1.MsgSetRoutingIsmDomain\x1a\x45.hyperlane.core.interchain_security.v1.MsgSetRoutingIsmDomainResponse\x12\xa4\x01\n\x16RemoveRoutingIsmDomain\x12@.hyperlane.core.interchain_security.v1.MsgRemoveRoutingIsmDomain\x1aH.hyperlane.core.interchain_security.v1.MsgRemoveRoutingIsmDomainResponse\x12\xa1\x01\n\x15UpdateRoutingIsmOwner\x12?.hyperlane.core.interchain_security.v1.MsgUpdateRoutingIsmOwner\x1aG.hyperlane.core.interchain_security.v1.MsgUpdateRoutingIsmOwnerResponse\x12\x95\x01\n\x11\x41nnounceValidator\x12;.hyperlane.core.interchain_security.v1.MsgAnnounceValidator\x1a\x43.hyperlane.core.interchain_security.v1.MsgAnnounceValidatorResponse\x1a\x05\x80\xe7\xb0*\x01\x42\xb8\x02\n)com.hyperlane.core.interchain_security.v1B\x07TxProtoP\x01ZOgithub.com/bcp-innovations/hyperlane-cosmos/x/core/01_interchain_security/types\xa2\x02\x03HCI\xaa\x02$Hyperlane.Core.InterchainSecurity.V1\xca\x02$Hyperlane\\Core\\InterchainSecurity\\V1\xe2\x02\x30Hyperlane\\Core\\InterchainSecurity\\V1\\GPBMetadata\xea\x02\'Hyperlane::Core::InterchainSecurity::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'hyperlane.core.interchain_security.v1.tx_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n)com.hyperlane.core.interchain_security.v1B\007TxProtoP\001ZOgithub.com/bcp-innovations/hyperlane-cosmos/x/core/01_interchain_security/types\242\002\003HCI\252\002$Hyperlane.Core.InterchainSecurity.V1\312\002$Hyperlane\\Core\\InterchainSecurity\\V1\342\0020Hyperlane\\Core\\InterchainSecurity\\V1\\GPBMetadata\352\002\'Hyperlane::Core::InterchainSecurity::V1'
  _globals['_MSGCREATEMESSAGEIDMULTISIGISM']._loaded_options = None
  _globals['_MSGCREATEMESSAGEIDMULTISIGISM']._serialized_options = b'\202\347\260*\007creator\212\347\260**hyperlane/v1/MsgCreateMessageIdMultisigIsm'
  _globals['_MSGCREATEMESSAGEIDMULTISIGISMRESPONSE'].fields_by_name['id']._loaded_options = None
  _globals['_MSGCREATEMESSAGEIDMULTISIGISMRESPONSE'].fields_by_name['id']._serialized_options = b'\310\336\037\000\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_MSGCREATEMERKLEROOTMULTISIGISM']._loaded_options = None
  _globals['_MSGCREATEMERKLEROOTMULTISIGISM']._serialized_options = b'\202\347\260*\007creator\212\347\260*+hyperlane/v1/MsgCreateMerkleRootMultisigIsm'
  _globals['_MSGCREATEMERKLEROOTMULTISIGISMRESPONSE'].fields_by_name['id']._loaded_options = None
  _globals['_MSGCREATEMERKLEROOTMULTISIGISMRESPONSE'].fields_by_name['id']._serialized_options = b'\310\336\037\000\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_MSGCREATENOOPISM']._loaded_options = None
  _globals['_MSGCREATENOOPISM']._serialized_options = b'\202\347\260*\007creator\212\347\260*\035hyperlane/v1/MsgCreateNoopIsm'
  _globals['_MSGCREATENOOPISMRESPONSE'].fields_by_name['id']._loaded_options = None
  _globals['_MSGCREATENOOPISMRESPONSE'].fields_by_name['id']._serialized_options = b'\310\336\037\000\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_MSGANNOUNCEVALIDATOR'].fields_by_name['mailbox_id']._loaded_options = None
  _globals['_MSGANNOUNCEVALIDATOR'].fields_by_name['mailbox_id']._serialized_options = b'\310\336\037\000\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_MSGANNOUNCEVALIDATOR']._loaded_options = None
  _globals['_MSGANNOUNCEVALIDATOR']._serialized_options = b'\202\347\260*\007creator\212\347\260*!hyperlane/v1/MsgAnnounceValidator'
  _globals['_MSGCREATEROUTINGISM'].fields_by_name['routes']._loaded_options = None
  _globals['_MSGCREATEROUTINGISM'].fields_by_name['routes']._serialized_options = b'\310\336\037\000'
  _globals['_MSGCREATEROUTINGISM']._loaded_options = None
  _globals['_MSGCREATEROUTINGISM']._serialized_options = b'\202\347\260*\007creator\212\347\260* hyperlane/v1/MsgCreateRoutingIsm'
  _globals['_MSGCREATEROUTINGISMRESPONSE'].fields_by_name['id']._loaded_options = None
  _globals['_MSGCREATEROUTINGISMRESPONSE'].fields_by_name['id']._serialized_options = b'\310\336\037\000\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_MSGSETROUTINGISMDOMAIN'].fields_by_name['ism_id']._loaded_options = None
  _globals['_MSGSETROUTINGISMDOMAIN'].fields_by_name['ism_id']._serialized_options = b'\310\336\037\000\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_MSGSETROUTINGISMDOMAIN'].fields_by_name['route']._loaded_options = None
  _globals['_MSGSETROUTINGISMDOMAIN'].fields_by_name['route']._serialized_options = b'\310\336\037\000'
  _globals['_MSGSETROUTINGISMDOMAIN']._loaded_options = None
  _globals['_MSGSETROUTINGISMDOMAIN']._serialized_options = b'\202\347\260*\005owner\212\347\260*6hyperlane/v1/MsgCreateRoMsgSetRoutingIsmDomainutingIsm'
  _globals['_MSGREMOVEROUTINGISMDOMAIN'].fields_by_name['ism_id']._loaded_options = None
  _globals['_MSGREMOVEROUTINGISMDOMAIN'].fields_by_name['ism_id']._serialized_options = b'\310\336\037\000\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_MSGREMOVEROUTINGISMDOMAIN']._loaded_options = None
  _globals['_MSGREMOVEROUTINGISMDOMAIN']._serialized_options = b'\202\347\260*\005owner\212\347\260*&hyperlane/v1/MsgRemoveRoutingIsmDomain'
  _globals['_MSGUPDATEROUTINGISMOWNER'].fields_by_name['ism_id']._loaded_options = None
  _globals['_MSGUPDATEROUTINGISMOWNER'].fields_by_name['ism_id']._serialized_options = b'\310\336\037\000\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_MSGUPDATEROUTINGISMOWNER'].fields_by_name['new_owner']._loaded_options = None
  _globals['_MSGUPDATEROUTINGISMOWNER'].fields_by_name['new_owner']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGUPDATEROUTINGISMOWNER']._loaded_options = None
  _globals['_MSGUPDATEROUTINGISMOWNER']._serialized_options = b'\202\347\260*\005owner\212\347\260*%hyperlane/v1/MsgUpdateRoutingIsmOwner'
  _globals['_MSG']._loaded_options = None
  _globals['_MSG']._serialized_options = b'\200\347\260*\001'
  _globals['_MSGCREATEMESSAGEIDMULTISIGISM']._serialized_start=234
  _globals['_MSGCREATEMESSAGEIDMULTISIGISM']._serialized_end=414
  _globals['_MSGCREATEMESSAGEIDMULTISIGISMRESPONSE']._serialized_start=416
  _globals['_MSGCREATEMESSAGEIDMULTISIGISMRESPONSE']._serialized_end=540
  _globals['_MSGCREATEMERKLEROOTMULTISIGISM']._serialized_start=543
  _globals['_MSGCREATEMERKLEROOTMULTISIGISM']._serialized_end=725
  _globals['_MSGCREATEMERKLEROOTMULTISIGISMRESPONSE']._serialized_start=727
  _globals['_MSGCREATEMERKLEROOTMULTISIGISMRESPONSE']._serialized_end=852
  _globals['_MSGCREATENOOPISM']._serialized_start=854
  _globals['_MSGCREATENOOPISM']._serialized_end=946
  _globals['_MSGCREATENOOPISMRESPONSE']._serialized_start=948
  _globals['_MSGCREATENOOPISMRESPONSE']._serialized_end=1059
  _globals['_MSGANNOUNCEVALIDATOR']._serialized_start=1062
  _globals['_MSGANNOUNCEVALIDATOR']._serialized_end=1365
  _globals['_MSGANNOUNCEVALIDATORRESPONSE']._serialized_start=1367
  _globals['_MSGANNOUNCEVALIDATORRESPONSE']._serialized_end=1397
  _globals['_MSGCREATEROUTINGISM']._serialized_start=1400
  _globals['_MSGCREATEROUTINGISM']._serialized_end=1574
  _globals['_MSGCREATEROUTINGISMRESPONSE']._serialized_start=1576
  _globals['_MSGCREATEROUTINGISMRESPONSE']._serialized_end=1690
  _globals['_MSGSETROUTINGISMDOMAIN']._serialized_start=1693
  _globals['_MSGSETROUTINGISMDOMAIN']._serialized_end=1976
  _globals['_MSGSETROUTINGISMDOMAINRESPONSE']._serialized_start=1978
  _globals['_MSGSETROUTINGISMDOMAINRESPONSE']._serialized_end=2010
  _globals['_MSGREMOVEROUTINGISMDOMAIN']._serialized_start=2013
  _globals['_MSGREMOVEROUTINGISMDOMAIN']._serialized_end=2233
  _globals['_MSGREMOVEROUTINGISMDOMAINRESPONSE']._serialized_start=2235
  _globals['_MSGREMOVEROUTINGISMDOMAINRESPONSE']._serialized_end=2270
  _globals['_MSGUPDATEROUTINGISMOWNER']._serialized_start=2273
  _globals['_MSGUPDATEROUTINGISMOWNER']._serialized_end=2569
  _globals['_MSGUPDATEROUTINGISMOWNERRESPONSE']._serialized_start=2571
  _globals['_MSGUPDATEROUTINGISMOWNERRESPONSE']._serialized_end=2605
  _globals['_MSG']._serialized_start=2608
  _globals['_MSG']._serialized_end=3911
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from hyperlane.core.v1 import query_pb2 as hyperlane_dot_core_dot_v1_dot_query__pb2


class QueryStub(object):
    """Query defines the module Query service.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Mailboxes = channel.unary_unary(
                '/hyperlane.core.v1.Query/Mailboxes',
                request_serializer=hyperlane_dot_core_dot_v1_dot_query__pb2.QueryMailboxesRequest.SerializeToString,
                response_deserializer=hyperlane_dot_core_dot_v1_dot_query__pb2.QueryMailboxesResponse.FromString,
                _registered_method=True)
        self.Mailbox = channel.unary_unary(
                '/hyperlane.core.v1.Query/Mailbox',
                request_serializer=hyperlane_dot_core_dot_v1_dot_query__pb2.QueryMailboxRequest.SerializeToString,
                response_deserializer=hyperlane_dot_core_dot_v1_dot_query__pb2.QueryMailboxResponse.FromString,
                _registered_method=True)
        self.Delivered = channel.unary_unary(
                '/hyperlane.core.v1.Query/Delivered',
                request_serializer=hyperlane_dot_core_dot_v1_dot_query__pb2.QueryDeliveredRequest.SerializeToString,
                response_deserializer=hyperlane_dot_core_dot_v1_dot_query__pb2.QueryDeliveredResponse.FromString,
                _registered_method=True)
        self.RecipientIsm = channel.unary_unary(
                '/hyperlane.core.v1.Query/RecipientIsm',
                request_serializer=hyperlane_dot_core_dot_v1_dot_query__pb2.QueryRecipientIsmRequest.SerializeToString,
                response_deserializer=hyperlane_dot_core_dot_v1_dot_query__pb2.QueryRecipientIsmResponse.FromString,
                _registered_method=True)
        self.VerifyDryRun = channel.unary_unary(
                '/hyperlane.core.v1.Query/VerifyDryRun',
                request_serializer=hyperlane_dot_core_dot_v1_dot_query__pb2.QueryVerifyDryRunRequest.SerializeToString,
                response_deserializer=hyperlane_dot_core_dot_v1_dot_query__pb2.QueryVerifyDryRunResponse.FromString,
                _registered_method=True)
        self.RegisteredISMs = channel.unary_unary(
                '/hyperlane.core.v1.Query/RegisteredISMs',
                request_serializer=hyperlane_dot_core_dot_v1_dot_query__pb2.QueryRegisteredISMs.SerializeToString,
                response_deserializer=hyperlane_dot_core_dot_v1_dot_query__pb2.QueryRegisteredISMsResponse.FromString,
                _registered_method=True)
        self.RegisteredHooks = channel.unary_unary(
                '/hyperlane.core.v1.Query/RegisteredHooks',
                request_serializer=hyperlane_dot_core_dot_v1_dot_query__pb2.QueryRegisteredHooks.SerializeToString,
                response_deserializer=hyperlane_dot_core_dot_v1_dot_query__pb2.QueryRegisteredHooksResponse.FromString,
                _registered_method=True)
        self.RegisteredApps = channel.unary_unary(
                '/hyperlane.core.v1.Query/RegisteredApps',
                request_serializer=hyperlane_dot_core_dot_v1_dot_query__pb2.QueryRegisteredApps.SerializeToString,
                response_deserializer=hyperlane_dot_core_dot_v1_dot_query__pb2.QueryRegisteredAppsResponse.FromString,
                _registered_method=True)


class QueryServicer(object):
    """Query defines the module Query service.
    """

    def Mailboxes(self, request, context):
        """Mailboxes ...
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Mailbox(self, request, context):
        """Mailbox ...
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Delivered(self, request, context):
        """Delivered ...
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RecipientIsm(self, request, context):
        """RecipientIsm returns the recipient ISM ID for a registered application.

        The recipient is globally unique as every application ID registered on the
        core module is unique. This means that one application cannot be registered
        to two mailboxes, resulting in a mailbox-independent lookup.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def VerifyDryRun(self, request, context):
        """VerifyDryRun ...
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RegisteredISMs(self, request, context):
        """RegisteredISMs ...
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RegisteredHooks(self, request, context):
        """RegisteredHooks ...
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RegisteredApps(self, request, context):
        """RegisteredApps ...
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_QueryServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Mailboxes': grpc.unary_unary_rpc_method_handler(
                    servicer.Mailboxes,
                    request_deserializer=hyperlane_dot_core_dot_v1_dot_query__pb2.QueryMailboxesRequest.FromString,
                    response_serializer=hyperlane_dot_core_dot_v1_dot_query__pb2.QueryMailboxesResponse.SerializeToString,
            ),
            'Mailbox': grpc.unary_unary_rpc_method_handler(
                    servicer.Mailbox,
                    request_deserializer=hyperlane_dot_core_dot_v1_dot_query__pb2.QueryMailboxRequest.FromString,
                    response_serializer=hyperlane_dot_core_dot_v1_dot_query__pb2.QueryMailboxResponse.SerializeToString,
            ),
            'Delivered': grpc.unary_unary_rpc_method_handler(
                    servicer.Delivered,
                    request_deserializer=hyperlane_dot_core_dot_v1_dot_query__pb2.QueryDeliveredRequest.FromString,
                    response_serializer=hyperlane_dot_core_dot_v1_dot_query__pb2.QueryDeliveredResponse.SerializeToString,
            ),
            'RecipientIsm': grpc.unary_unary_rpc_method_handler(
                    servicer.RecipientIsm,
                    request_deserializer=hyperlane_dot_core_dot_v1_dot_query__pb2.QueryRecipientIsmRequest.FromString,
                    response_serializer=hyperlane_dot_core_dot_v1_dot_query__pb2.QueryRecipientIsmResponse.SerializeToString,
            ),
            'VerifyDryRun': grpc.unary_unary_rpc_method_handler(
                    servicer.VerifyDryRun,
                    request_deserializer=hyperlane_dot_core_dot_v1_dot_query__pb2.QueryVerifyDryRunRequest.FromString,
                    response_serializer=hyperlane_dot_core_dot_v1_dot_query__pb2.QueryVerifyDryRunResponse.SerializeToString,
            ),
            'RegisteredISMs': grpc.unary_unary_rpc_method_handler(
                    servicer.RegisteredISMs,
                    request_deserializer=hyperlane_dot_core_dot_v1_dot_query__pb2.QueryRegisteredISMs.FromString,
                    response_serializer=hyperlane_dot_core_dot_v1_dot_query__pb2.QueryRegisteredISMsResponse.SerializeToString,
            ),
            'RegisteredHooks': grpc.unary_unary_rpc_method_handler(
                    servicer.RegisteredHooks,
                    request_deserializer=hyperlane_dot_core_dot_v1_dot_query__pb2.QueryRegisteredHooks.FromString,
                    response_serializer=hyperlane_dot_core_dot_v1_dot_query__pb2.QueryRegisteredHooksResponse.SerializeToString,
            ),
            'RegisteredApps': grpc.unary_unary_rpc_method_handler(
                    servicer.RegisteredApps,
                    request_deserializer=hyperlane_dot_core_dot_v1_dot_query__pb2.QueryRegisteredApps.FromString,
                    response_serializer=hyperlane_dot_core_dot_v1_dot_query__pb2.QueryRegisteredAppsResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'hyperlane.core.v1.Query', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('hyperlane.core.v1.Query', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class Query(object):
    """Query defines the module Query service.
    """

    @staticmethod
    def Mailboxes(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/hyperlane.core.v1.Query/Mailboxes',
            hyperlane_dot_core_dot_v1_dot_query__pb2.QueryMailboxesRequest.SerializeToString,
            hyperlane_dot_core_dot_v1_dot_query__pb2.QueryMailboxesResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Mailbox(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/hyperlane.core.v1.Query/Mailbox',
            hyperlane_dot_core_dot_v1_dot_query__pb2.QueryMailboxRequest.SerializeToString,
            hyperlane_dot_core_dot_v1_dot_query__pb2.QueryMailboxResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Delivered(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/hyperlane.core.v1.Query/Delivered',
            hyperlane_dot_core_dot_v1_dot_query__pb2.QueryDeliveredRequest.SerializeToString,
            hyperlane_dot_core_dot_v1_dot_query__pb2.QueryDeliveredResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def RecipientIsm(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/hyperlane.core.v1.Query/RecipientIsm',
            hyperlane_dot_core_dot_v1_dot_query__pb2.QueryRecipientIsmRequest.SerializeToString,
            hyperlane_dot_core_dot_v1_dot_query__pb2.QueryRecipientIsmResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def VerifyDryRun(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/hyperlane.core.v1.Query/VerifyDryRun',
            hyperlane_dot_core_dot_v1_dot_query__pb2.QueryVerifyDryRunRequest.SerializeToString,
            hyperlane_dot_core_dot_v1_dot_query__pb2.QueryVerifyDryRunResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def RegisteredISMs(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/hyperlane.core.v1.Query/RegisteredISMs',
            hyperlane_dot_core_dot_v1_dot_query__pb2.QueryRegisteredISMs.SerializeToString,
            hyperlane_dot_core_dot_v1_dot_query__pb2.QueryRegisteredISMsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def RegisteredHooks(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/hyperlane.core.v1.Query/RegisteredHooks',
            hyperlane_dot_core_dot_v1_dot_query__pb2.QueryRegisteredHooks.SerializeToString,
            hyperlane_dot_core_dot_v1_dot_query__pb2.QueryRegisteredHooksResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def RegisteredApps(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/hyperlane.core.v1.Query/RegisteredApps',
            hyperlane_dot_core_dot_v1_dot_query__pb2.QueryRegisteredApps.SerializeToString,
            hyperlane_dot_core_dot_v1_dot_query__pb2.QueryRegisteredAppsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from hyperlane.core.post_dispatch.v1 import tx_pb2 as hyperlane_dot_core_dot_post__dispatch_dot_v1_dot_tx__pb2


class MsgStub(object):
    """Msg defines the module Msg service.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CreateIgp = channel.unary_unary(
                '/hyperlane.core.post_dispatch.v1.Msg/CreateIgp',
                request_serializer=hyperlane_dot_core_dot_post__dispatch_dot_v1_dot_tx__pb2.MsgCreateIgp.SerializeToString,
                response_deserializer=hyperlane_dot_core_dot_post__dispatch_dot_v1_dot_tx__pb2.MsgCreateIgpResponse.FromString,
                _registered_method=True)
        self.SetIgpOwner = channel.unary_unary(
                '/hyperlane.core.post_dispatch.v1.Msg/SetIgpOwner',
                request_serializer=hyperlane_dot_core_dot_post__dispatch_dot_v1_dot_tx__pb2.MsgSetIgpOwner.SerializeToString,
                response_deserializer=hyperlane_dot_core_dot_post__dispatch_dot_v1_dot_tx__pb2.MsgSetIgpOwnerResponse.FromString,
                _registered_method=True)
        self.SetDestinationGasConfig = channel.unary_unary(
                '/hyperlane.core.post_dispatch.v1.Msg/SetDestinationGasConfig',
                request_serializer=hyperlane_dot_core_dot_post__dispatch_dot_v1_dot_tx__pb2.MsgSetDestinationGasConfig.SerializeToString,
                response_deserializer=hyperlane_dot_core_dot_post__dispatch_dot_v1_dot_tx__pb2.MsgSetDestinationGasConfigResponse.FromString,
                _registered_method=True)
        self.PayForGas = channel.unary_unary(
                '/hyperlane.core.post_dispatch.v1.Msg/PayForGas',
                request_serializer=hyperlane_dot_core_dot_post__dispatch_dot_v1_dot_tx__pb2.MsgPayForGas.SerializeToString,
                response_deserializer=hyperlane_dot_core_dot_post__dispatch_dot_v1_dot_tx__pb2.MsgPayForGasResponse.FromString,
                _registered_method=True)
        self.Claim = channel.unary_unary(
                '/hyperlane.core.post_dispatch.v1.Msg/Claim',
                request_serializer=hyperlane_dot_core_dot_post__dispatch_dot_v1_dot_tx__pb2.MsgClaim.SerializeToString,
                response_deserializer=hyperlane_dot_core_dot_post__dispatch_dot_v1_dot_tx__pb2.MsgClaimResponse.FromString,
                _registered_method=True)
        self.CreateMerkleTreeHook = channel.unary_unary(
                '/hyperlane.core.post_dispatch.v1.Msg/CreateMerkleTreeHook',
                request_serializer=hyperlane_dot_core_dot_post__dispatch_dot_v1_dot_tx__pb2.MsgCreateMerkleTreeHook.SerializeToString,
                response_deserializer=hyperlane_dot_core_dot_post__dispatch_dot_v1_dot_tx__pb2.MsgCreateMerkleTreeHookResponse.FromString,
                _registered_method=True)
        self.CreateNoopHook = channel.unary_unary(
                '/hyperlane.core.post_dispatch.v1.Msg/CreateNoopHook',
                request_serializer=hyperlane_dot_core_dot_post__dispatch_dot_v1_dot_tx__pb2.MsgCreateNoopHook.SerializeToString,
                response_deserializer=hyperlane_dot_core_dot_post__dispatch_dot_v1_dot_tx__pb2.MsgCreateNoopHookResponse.FromString,
                _registered_method=True)


class MsgServicer(object):
    """Msg defines the module Msg service.
    """

    def CreateIgp(self, request, context):
        """CreateIgp ...
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetIgpOwner(self, request, context):
        """SetIgpOwner ...
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetDestinationGasConfig(self, request, context):
        """SetDestinationGasConfig ...
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PayForGas(self, request, context):
        """PayForGas ...
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Claim(self, request, context):
        """Claim ...
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateMerkleTreeHook(self, request, context):
        """CreateMerkleTreeHook ...
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateNoopHook(self, request, context):
        """CreateNoopHook ...
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_MsgServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'CreateIgp': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateIgp,
                    request_deserializer=hyperlane_dot_core_dot_post__dispatch_dot_v1_dot_tx__pb2.MsgCreateIgp.FromString,
                    response_serializer=hyperlane_dot_core_dot_post__dispatch_dot_v1_dot_tx__pb2.MsgCreateIgpResponse.SerializeToString,
            ),
            'SetIgpOwner': grpc.unary_unary_rpc_method_handler(
                    servicer.SetIgpOwner,
                    request_deserializer=hyperlane_dot_core_dot_post__dispatch_dot_v1_dot_tx__pb2.MsgSetIgpOwner.FromString,
                    response_serializer=hyperlane_dot_core_dot_post__dispatch_dot_v1_dot_tx__pb2.MsgSetIgpOwnerResponse.SerializeToString,
            ),
            'SetDestinationGasConfig': grpc.unary_unary_rpc_method_handler(
                    servicer.SetDestinationGasConfig,
                    request_deserializer=hyperlane_dot_core_dot_post__dispatch_dot_v1_dot_tx__pb2.MsgSetDestinationGasConfig.FromString,
                    response_serializer=hyperlane_dot_core_dot_post__dispatch_dot_v1_dot_tx__pb2.MsgSetDestinationGasConfigResponse.SerializeToString,
            ),
            'PayForGas': grpc.unary_unary_rpc_method_handler(
                    servicer.PayForGas,
                    request_deserializer=hyperlane_dot_core_dot_post__dispatch_dot_v1_dot_tx__pb2.MsgPayForGas.FromString,
                    response_serializer=hyperlane_dot_core_dot_post__dispatch_dot_v1_dot_tx__pb2.MsgPayForGasResponse.SerializeToString,
            ),
            'Claim': grpc.unary_unary_rpc_method_handler(
                    servicer.Claim,
                    request_deserializer=hyperlane_dot_core_dot_post__dispatch_dot_v1_dot_tx__pb2.MsgClaim.FromString,
                    response_serializer=hyperlane_dot_core_dot_post__dispatch_dot_v1_dot_tx__pb2.MsgClaimResponse.SerializeToString,
            ),
            'CreateMerkleTreeHook': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateMerkleTreeHook,
                    request_deserializer=hyperlane_dot_core_dot_post__dispatch_dot_v1_dot_tx__pb2.MsgCreateMerkleTreeHook.FromString,
                    response_serializer=hyperlane_dot_core_dot_post__dispatch_dot_v1_dot_tx__pb2.MsgCreateMerkleTreeHookResponse.SerializeToString,
            ),
            'CreateNoopHook': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateNoopHook,
                    request_deserializer=hyperlane_dot_core_dot_post__dispatch_dot_v1_dot_tx__pb2.MsgCreateNoopHook.FromString,
                    response_serializer=hyperlane_dot_core_dot_post__dispatch_dot_v1_dot_tx__pb2.MsgCreateNoopHookResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'hyperlane.core.post_dispatch.v1.Msg', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('hyperlane.core.post_dispatch.v1.Msg', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class Msg(object):
    """Msg defines the module Msg service.
    """

    @staticmethod
    def CreateIgp(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/hyperlane.core.post_dispatch.v1.Msg/CreateIgp',
            hyperlane_dot_core_dot_post__dispatch_dot_v1_dot_tx__pb2.MsgCreateIgp.SerializeToString,
            hyperlane_dot_core_dot_post__dispatch_dot_v1_dot_tx__pb2.MsgCreateIgpResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def SetIgpOwner(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/hyperlane.core.post_dispatch.v1.Msg/SetIgpOwner',
            hyperlane_dot_core_dot_post__dispatch_dot_v1_dot_tx__pb2.MsgSetIgpOwner.SerializeToString,
            hyperlane_dot_core_dot_post__dispatch_dot_v1_dot_tx__pb2.MsgSetIgpOwnerResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def SetDestinationGasConfig(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/hyperlane.core.post_dispatch.v1.Msg/SetDestinationGasConfig',
            hyperlane_dot_core_dot_post__dispatch_dot_v1_dot_tx__pb2.MsgSetDestinationGasConfig.SerializeToString,
            hyperlane_dot_core_dot_post__dispatch_dot_v1_dot_tx__pb2.MsgSetDestinationGasConfigResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def PayForGas(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/hyperlane.core.post_dispatch.v1.Msg/PayForGas',
            hyperlane_dot_core_dot_post__dispatch_dot_v1_dot_tx__pb2.MsgPayForGas.SerializeToString,
            hyperlane_dot_core_dot_post__dispatch_dot_v1_dot_tx__pb2.MsgPayForGasResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Claim(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/hyperlane.core.post_dispatch.v1.Msg/Claim',
            hyperlane_dot_core_dot_post__dispatch_dot_v1_dot_tx__pb2.MsgClaim.SerializeToString,
            hyperlane_dot_core_dot_post__dispatch_dot_v1_dot_tx__pb2.MsgClaimResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def CreateMerkleTreeHook(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/hyperlane.core.post_dispatch.v1.Msg/CreateMerkleTreeHook',
            hyperlane_dot_core_dot_post__dispatch_dot_v1_dot_tx__pb2.MsgCreateMerkleTreeHook.SerializeToString,
            hyperlane_dot_core_dot_post__dispatch_dot_v1_dot_tx__pb2.MsgCreateMerkleTreeHookResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def CreateNoopHook(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/hyperlane.core.post_dispatch.v1.Msg/CreateNoopHook',
            hyperlane_dot_core_dot_post__dispatch_dot_v1_dot_tx__pb2.MsgCreateNoopHook.SerializeToString,
            hyperlane_dot_core_dot_post__dispatch_dot_v1_dot_tx__pb2.MsgCreateNoopHookResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)
